#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-09-25 14:34:21.593357

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""
from pycatia.eno_cd5_interfaces.cd5_save_items import CD5SaveItems
from pycatia.system_interfaces.any_object import AnyObject


class CD5SaveOperation(AnyObject):
    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.AnyObject
                |                     CD5SaveOperation
                | 
                | Represents a Save Operation Object.
                | 
                | Various properties which are applicable for the complete save operation can be
                | set using this.
                | Also, end-user may either run the Save operation as per customization done so
                | far or open the Advanced Save panel to finalize customization and run the Save
                | manually.
                | 
                | Example:
                | 
                |       The following example indicates how to create a ENOVIA V6 Save
                |       Operation.
                |      
                | 
                |      Dim oCD5Engine As CD5EngineV6R2014x
                |      Set oCD5Engine = CATIA.GetItem("CD5EngineV6R2014x")
                |      Dim oSaveOperation As CD5SaveOperation
                |      Set oSaveOperation = oCD5Engine.CreateSaveOperation(CD5SaveOperation_Session)
                |
                | See also:
                |     CD5SaveItems
    
    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.cd5_save_operation = com_object

    @property
    def allow_disk_save(self) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property AllowDiskSave() As boolean
                | 
                |     Returns (gets) or sets the value of the Save option "Allow Disk
                |     Save".
                | 
                |     Example:
                | 
                |           The following example sets the Allow Disk Save option to
                |           True.
                |
                |          oSaveOperation.AllowDiskSave = True

        :rtype: bool
        """

        return self.cd5_save_operation.AllowDiskSave

    @allow_disk_save.setter
    def allow_disk_save(self, value: bool):
        """
        :param bool value:
        """

        self.cd5_save_operation.AllowDiskSave = value

    @property
    def comment(self) -> str:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property Comment() As CATBSTR
                | 
                |     Returns (gets) or sets the value of the Save Comment.
                | 
                |     Example:
                | 
                |           The following example sets the Save Comment to
                |           "ABC".
                |
                |          oSaveOperation.Comment = "ABC"

        :rtype: str
        """

        return self.cd5_save_operation.Comment

    @comment.setter
    def comment(self, value: str):
        """
        :param str value:
        """

        self.cd5_save_operation.Comment = value

    @property
    def create_version(self) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property CreateVersion() As boolean
                | 
                |     Returns (gets) or sets the value of the Save option "Create Version". The
                |     default value is picked from the LCO/GCO.
                | 
                |     Example:
                | 
                |           The following example sets the Create Version option to
                |           True.
                |
                |          oSaveOperation.CreateVersion = True

        :rtype: bool
        """

        return self.cd5_save_operation.CreateVersion

    @create_version.setter
    def create_version(self, value: bool):
        """
        :param bool value:
        """

        self.cd5_save_operation.CreateVersion = value

    @property
    def items(self) -> CD5SaveItems:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property Items() As CD5SaveItems (Read Only)
                | 
                |     Returns (gets) the collection of all the items in the scope of the
                |     Save.
                | 
                |     Example:
                | 
                |           The following example gets all the items in the scope of the
                |           Save.
                |          
                | 
                |          Dim oSaveItems As CD5SaveItems
                |          Set oSaveItems = oSaveOperation.Items

        :rtype: CD5SaveItems
        """

        return CD5SaveItems(self.cd5_save_operation.Items)

    @property
    def retain_lock(self) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property RetainLock() As boolean
                | 
                |     Returns (gets) or sets the value of the Save option "Retain Lock". The
                |     default value is picked from the LCO/GCO.
                | 
                |     Example:
                | 
                |           The following example sets the Retain Lock option to
                |           True.
                |
                |          oSaveOperation.RetainLock = True

        :rtype: bool
        """

        return self.cd5_save_operation.RetainLock

    @retain_lock.setter
    def retain_lock(self, value: bool):
        """
        :param bool value:
        """

        self.cd5_save_operation.RetainLock = value

    def run(self) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub Run()
                | 
                |     Runs the Save as per the cusomization done so far.
                | 
                |     Example:
                | 
                |           The following example executes the Save operation as per the
                |           customization done so far. 
                |
                |          oSaveOperation.Run

        :rtype: None
        """
        return self.cd5_save_operation.Run()

    def show_panel(self) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub ShowPanel()
                | 
                |     Shows the Save dialog as per the cusomization done so far.
                | 
                |     Example:
                | 
                |           The following example shows the Save panel as per the cusomization
                |           done so far.
                |
                |          oSaveOperation.ShowPanel

        :rtype: None
        """
        return self.cd5_save_operation.ShowPanel()

    def __repr__(self):
        return f'CD5SaveOperation(name="{self.name}")'



#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-06-11 12:40:47.360445

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""

from pycatia.system_interfaces.any_object import AnyObject


class HybridShape(AnyObject):
    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.AnyObject
                |                     HybridShape
                | 
                | Represents the hybrid shape object.
    
    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.hybrid_shape = com_object

    @property
    def thickness(self) -> 'HybridShape':
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property Thickness() As HybridShape (Read Only)
                | 
                |     Returns the thickness of the hybrid shape.
                |     The thickness is a CATIAHybridShapeThickness.
                | 
                |     Example:
                |         The following example returns the thickness ExtrudeThickness of the
                |         extrude Extrude.1 as the origin point of the axis system
                |         AxisSystem0:
                | 
                |          Dim Extrude1 As AnyObject
                |          Set Extrude1 = HybridBody1.HybridShapes.Item  ( "Extrude.1" ) 
                |          Dim Thickness1 As HybridShapeThickness
                |          Set Thickness1 = Extrude1.Thickness

        :rtype: HybridShape
        """

        return HybridShape(self.hybrid_shape.Thickness)

    def append_hybrid_shape(self, i_hybrid_shape: 'HybridShape') -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Sub AppendHybridShape(HybridShape iHybridShape)
                | 
                |     Appends a hybrid shape to another hybrid shape.
                | 
                |     Parameters:
                | 
                |         iHybridShape
                |             The hybrid shape to append. 
                | 
                |     Example:
                |         This example appends the hybrid shape newHybridShape to the hybrid
                |         shape oldHybridShape:
                | 
                |          oldHybridShape.AppendHybridShape (newHybridShape)

        :param HybridShape i_hybrid_shape:
        :rtype: None
        """
        return self.hybrid_shape.AppendHybridShape(i_hybrid_shape.com_object)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'append_hybrid_shape'
        # # vba_code = """
        # # Public Function append_hybrid_shape(hybrid_shape)
        # #     Dim iHybridShape (2)
        # #     hybrid_shape.AppendHybridShape iHybridShape
        # #     append_hybrid_shape = iHybridShape
        # # End Function
        # # """

        # # system_service = self.application.system_service
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def compute(self) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445))
                | o Sub Compute()
                | 
                |     Computes the result of the hybrid shape.

        :rtype: None
        """
        return self.hybrid_shape.Compute()

    def __repr__(self):
        return f'HybridShape(name="{self.name}")'



#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-07-06 14:02:20.222384

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""

from pycatia.hybrid_shape_interfaces.hybrid_shape_direction import HybridShapeDirection
from pycatia.hybrid_shape_interfaces.hybrid_shape_sweep import HybridShapeSweep
from pycatia.in_interfaces.reference import Reference
from pycatia.knowledge_interfaces.angle import Angle
from pycatia.knowledge_interfaces.length import Length


class HybridShapeSweepExplicit(HybridShapeSweep):
    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.AnyObject
                |                     MecModInterfaces.HybridShape
                |                         CATGSMIDLItf.HybridShapeSweep
                |                             HybridShapeSweepExplicit
                | 
                | Represents the hybrid shape Sweep explicit feature object.
                | Role: To access the data of the hybrid shape sweep explicit feature
                | object.
                | 
                | LICENSING INFORMATION: Creation of volume result requires GSO
                | License
                | if GSO License is not granted , setting of Volume context has not
                | effect
                | 
                | See also:
                |     HybridShapeFactory
    
    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.hybrid_shape_sweep_explicit = com_object

    @property
    def angle_law(self) -> Reference:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property AngleLaw() As Reference
                | 
                |     Returns or sets the angle law feature associated to the reference
                |     surface.
                | 
                |     Parameters:
                | 
                |         oElem
                |             Angle law element. return value for CATScript applications, with
                |             (IDLRETVAL) function type 
                | 
                |     See also:
                |         Reference 
                |     See also:
                |         HybridShapeFactory

        :rtype: Reference
        """

        return Reference(self.hybrid_shape_sweep_explicit.AngleLaw)

    @angle_law.setter
    def angle_law(self, reference_law: Reference):
        """
        :param Reference reference_law:
        """

        self.hybrid_shape_sweep_explicit.AngleLaw = reference_law.com_object

    @property
    def angle_law_inversion(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property AngleLawInversion() As long
                | 
                |     Returns or sets the angle law inversion information.
                | 
                |     Parameters:
                | 
                |         oElem
                |             Angle law inversion information. 
                | 
                |     See also:
                |         HybridShapeFactory

        :rtype: int
        """

        return self.hybrid_shape_sweep_explicit.AngleLawInversion

    @angle_law_inversion.setter
    def angle_law_inversion(self, value: int):
        """
        :param int value:
        """

        self.hybrid_shape_sweep_explicit.AngleLawInversion = value

    @property
    def angle_law_type(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property AngleLawType() As long
                | 
                |     Returns or sets the angle law type associated to the reference
                |     surface.
                | 
                |     Parameters:
                | 
                |         oElem
                |             Angle law type. 
                | 
                |     See also:
                |         HybridShapeFactory

        :rtype: int
        """

        return self.hybrid_shape_sweep_explicit.AngleLawType

    @angle_law_type.setter
    def angle_law_type(self, value: int):
        """
        :param int value:
        """

        self.hybrid_shape_sweep_explicit.AngleLawType = value

    @property
    def canonical_detection(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property CanonicalDetection() As long
                | 
                |     Returns or sets whether canonical surfaces of the swept surface are
                |     detected.
                |     Legal values:
                |     0 No detection of canonical surface is performed.
                |     2 Detection of canonical surfaces is performed.

        :rtype: int
        """

        return self.hybrid_shape_sweep_explicit.CanonicalDetection

    @canonical_detection.setter
    def canonical_detection(self, value: int):
        """
        :param int value:
        """

        self.hybrid_shape_sweep_explicit.CanonicalDetection = value

    @property
    def context(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property Context() As long
                | 
                |     Returns or sets the context on Sweep feature.
                | 
                |         0 This option creates Swept surface.
                |         1 This option creates Swept volume.
                | 
                | 
                |     Note: Setting volume result requires GSO License.
                | 
                |     Example:
                |         This example retrieves in oContext the context for the Sweep hybrid
                |         shape feature.
                | 
                |          Dim oContext
                |          Set oContext = Sweep.Context

        :rtype: int
        """

        return self.hybrid_shape_sweep_explicit.Context

    @context.setter
    def context(self, value: int):
        """
        :param int value:
        """

        self.hybrid_shape_sweep_explicit.Context = value

    @property
    def first_guide_crv(self) -> Reference:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property FirstGuideCrv() As Reference
                | 
                |     Gets the first guide curve.
                | 
                |     Parameters:
                | 
                |         oElem
                |             Guide curve. return value for CATScript applications, with
                |             (IDLRETVAL) function type 
                | 
                |     See also:
                |         Reference 
                |     Returns:
                |         HRESULT S_OK if Ok E_FAIL else return error code for C++
                |         Implementations 
                |     See also:
                |         HybridShapeFactory

        :rtype: Reference
        """

        return Reference(self.hybrid_shape_sweep_explicit.FirstGuideCrv)

    @first_guide_crv.setter
    def first_guide_crv(self, reference_curve: Reference):
        """
        :param Reference reference_curve:
        """

        self.hybrid_shape_sweep_explicit.FirstGuideCrv = reference_curve.com_object

    @property
    def guide_deviation(self) -> Length:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property GuideDeviation() As Length (Read Only)
                | 
                |     Returns deviation value (length) from guide curves allowed during sweeping
                |     operation in order to smooth it.

        :rtype: Length
        """

        return Length(self.hybrid_shape_sweep_explicit.GuideDeviation)

    @property
    def guide_deviation_activity(self) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property GuideDeviationActivity() As boolean
                | 
                |     Returns or sets information whether a deviation from guide curves is
                |     allowed or not.
                |     Gives the information on performing smoothing during sweeping
                |     operation.
                |     TRUE or FALSE (FALSE if not specified).

        :rtype: bool
        """

        return self.hybrid_shape_sweep_explicit.GuideDeviationActivity

    @guide_deviation_activity.setter
    def guide_deviation_activity(self, value: bool):
        """
        :param bool value:
        """

        self.hybrid_shape_sweep_explicit.GuideDeviationActivity = value

    @property
    def guide_projection(self) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property GuideProjection() As boolean
                | 
                |     Returns or sets the projection of the guide curve onto the reference plane
                |     in order to use it as spine, in pulling direction case only. Removes Spine if
                |     GuideProjection is set to TRUE.
                |     Legal values: True projection is required and False if not
                | 
                |     Example:
                | 
                |           This example sets that the GuideProjection mode of
                |          the Sweep hybrid shape sweep explicit feature to
                |          True.
                |          
                | 
                |          Sweep.GuideProjection = True

        :rtype: bool
        """

        return self.hybrid_shape_sweep_explicit.GuideProjection

    @guide_projection.setter
    def guide_projection(self, value: bool):
        """
        :param bool value:
        """

        self.hybrid_shape_sweep_explicit.GuideProjection = value

    @property
    def mode(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property Mode() As long
                | 
                |     Returns or sets positioning mode used for the profile.
                | 
                |     Parameters:
                | 
                |         oElem
                | 
                |             Values :
                |             = 1 - CATGSMPositionMode_NoneOrPositioned : no positioning,
                | 
                |             = 2 - CATGSMPositionMode_ExplicitSweep : the explicit profile is to be moved from its
                |                   initial plane to the first sweep plane,
                | 
                |             = 3 - CATGSMPositionMode_Develop : === DO NOT USE IN THIS CASE === 
                | 
                |     See also:
                |         HybridShapeFactory

        :rtype: int
        """

        return self.hybrid_shape_sweep_explicit.Mode

    @mode.setter
    def mode(self, value: int):
        """
        :param int value:
        """

        self.hybrid_shape_sweep_explicit.Mode = value

    @property
    def position_mode(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property PositionMode() As long
                | 
                |     Returns or sets positioning mode.
                |     Legal values:
                | 
                |     0
                |         CATGSMPositionMode_NoneOrPositioned. 
                |     1
                |         CATGSMPositionMode_ExplicitSweep. if a positioning operation is
                |         done.
                | 
                | Example:
                |     This example retrieves in oPosMode the position mode for the Sweep hybrid
                |     shape feature.
                | 
                |      oPosMode = Sweep.PositionMode

        :rtype: int
        """

        return self.hybrid_shape_sweep_explicit.PositionMode

    @position_mode.setter
    def position_mode(self, value: int):
        """
        :param int value:
        """

        self.hybrid_shape_sweep_explicit.PositionMode = value

    @property
    def positioned_profile(self) -> Reference:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property PositionedProfile() As Reference
                | 
                |     Returns or sets the positioning transformation associated to the explicit
                |     swept surface and which result corresponds to the positioned
                |     profile.
                | 
                |     Parameters:
                | 
                |         oElem
                |             Positioning transformation / positioned profile. return value for
                |             CATScript applications, with (IDLRETVAL) function type
                |             
                | 
                |     See also:
                |         Reference 
                |     See also:
                |         HybridShapeFactory

        :rtype: Reference
        """

        return Reference(self.hybrid_shape_sweep_explicit.PositionedProfile)

    @positioned_profile.setter
    def positioned_profile(self, reference_profile: Reference):
        """
        :param Reference reference_profile:
        """

        self.hybrid_shape_sweep_explicit.PositionedProfile = reference_profile.com_object

    @property
    def profile(self) -> Reference:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property Profile() As Reference
                | 
                |     Gets the profile to be swept out.
                | 
                |     Parameters:
                | 
                |         oElem
                |             Profile element. return value for CATScript applications, with
                |             (IDLRETVAL) function type 
                | 
                |     See also:
                |         Reference 
                |     Returns:
                |         HRESULT S_OK if Ok E_FAIL else return error code for C++
                |         Implementations 
                |     See also:
                |         HybridShapeFactory

        :rtype: Reference
        """

        return Reference(self.hybrid_shape_sweep_explicit.Profile)

    @profile.setter
    def profile(self, reference_profile: Reference):
        """
        :param Reference reference_profile:
        """

        self.hybrid_shape_sweep_explicit.Profile = reference_profile.com_object

    @property
    def profile_x_axis_computation_mode(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property ProfileXAxisComputationMode() As long
                | 
                |     Returns or sets the computation mode of the X axis (or direction) of the
                |     initial axis system (on the profile). Default value is
                |     CATGSMPositionDirCompMode_None when PosDirection(OutputDirection) is not
                |     specified and CATGSMPositionDirCompMode_User if OutputDirection is
                |     specified.
                |     Legal values:
                | 
                |     0
                |         CATGSMPositionDirCompMode_None. No X axis specified. 
                |     1
                |         CATGSMPositionDirCompMode_Tangent: the X axis is implicitly the tangent
                |         of the profile at the origin (the origin then HAS to be on the
                |         profile)
                |     2
                |         CATGSMPositionDirCompMode_User: the X axis is specified by a direction
                |         via SetPosDirection(UserInputDirection, 1)
                | 
                | Example:
                |     This example retrieves in oDirCompMode the Profile X Axis ComputationMode
                |     for the Sweep hybrid shape feature.
                | 
                |      oDirCompMode = Sweep.ProfileXAxisComputationMode

        :rtype: int
        """

        return self.hybrid_shape_sweep_explicit.ProfileXAxisComputationMode

    @profile_x_axis_computation_mode.setter
    def profile_x_axis_computation_mode(self, value: int):
        """
        :param int value:
        """

        self.hybrid_shape_sweep_explicit.ProfileXAxisComputationMode = value

    @property
    def pulling_direction(self) -> HybridShapeDirection:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property PullingDirection() As HybridShapeDirection
                | 
                |     Gets or sets the pulling direction
                |     If the direction is specified, the plane normal to this direction is taken
                |     as reference surface.
                | 
                |     Example:
                |         This example retrieves in ohDir the pulling direction feature for the
                |         Sweep hybrid shape feature.
                | 
                |          Dim ohDir As CATIAHybridShapeDirection
                |          Set ohDir = Sweep.PullingDirection

        :rtype: HybridShapeDirection
        """

        return HybridShapeDirection(self.hybrid_shape_sweep_explicit.PullingDirection)

    @pulling_direction.setter
    def pulling_direction(self, direction: HybridShapeDirection):
        """
        :param HybridShapeDirection direction:
        """

        self.hybrid_shape_sweep_explicit.PullingDirection = direction.com_object

    @property
    def reference(self) -> Reference:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property Reference() As Reference
                | 
                |     Returns or sets the reference surface (optional).
                | 
                |     Parameters:
                | 
                |         oElem
                |             Reference surface. return value for CATScript applications, with
                |             (IDLRETVAL) function type 
                | 
                |     See also:
                |         Reference

        :rtype: Reference
        """

        return Reference(self.hybrid_shape_sweep_explicit.Reference)

    @reference.setter
    def reference(self, reference: Reference):
        """
        :param Reference reference:
        """

        self.hybrid_shape_sweep_explicit.Reference = reference.com_object

    @property
    def second_guide_crv(self) -> Reference:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property SecondGuideCrv() As Reference
                | 
                |     Gets the second guide curve (optional).
                | 
                |     Parameters:
                | 
                |         oElem
                |             Guide curve. return value for CATScript applications, with
                |             (IDLRETVAL) function type 
                | 
                |     See also:
                |         Reference 
                |     Returns:
                |         HRESULT S_OK if Ok E_FAIL else return error code for C++
                |         Implementations 
                |     See also:
                |         HybridShapeFactory

        :rtype: Reference
        """

        return Reference(self.hybrid_shape_sweep_explicit.SecondGuideCrv)

    @second_guide_crv.setter
    def second_guide_crv(self, reference_curve: Reference):
        """
        :param Reference reference_curve:
        """

        self.hybrid_shape_sweep_explicit.SecondGuideCrv = reference_curve.com_object

    @property
    def smooth_activity(self) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property SmoothActivity() As boolean
                | 
                |     Returns or sets information whether sweeping operation is smoothed or
                |     not.
                |     TRUE or FALSE (FALSE if not specified).

        :rtype: bool
        """

        return self.hybrid_shape_sweep_explicit.SmoothActivity

    @smooth_activity.setter
    def smooth_activity(self, value: bool):
        """
        :param bool value:
        """

        self.hybrid_shape_sweep_explicit.SmoothActivity = value

    @property
    def smooth_angle_threshold(self) -> Angle:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property SmoothAngleThreshold() As Angle (Read Only)
                | 
                |     Returns angular threshold.

        :rtype: Angle
        """

        return Angle(self.hybrid_shape_sweep_explicit.SmoothAngleThreshold)

    @property
    def solution_no(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property SolutionNo() As long
                | 
                |     Returns or sets the choice number, which corresponds to each solution of a
                |     given explicit sweep case.
                |     For example: a explicit sweep with reference surface leads to four possible
                |     solutions.

        :rtype: int
        """

        return self.hybrid_shape_sweep_explicit.SolutionNo

    @solution_no.setter
    def solution_no(self, value: int):
        """
        :param int value:
        """

        self.hybrid_shape_sweep_explicit.SolutionNo = value

    @property
    def spine(self) -> Reference:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property Spine() As Reference
                | 
                |     Returns or sets the spine (optional) for sweep operation.
                | 
                |     Parameters:
                | 
                |         oElem
                |             Spine curve. return value for CATScript applications, with
                |             (IDLRETVAL) function type 
                | 
                |     See also:
                |         Reference 
                |     See also:
                |         HybridShapeFactory

        :rtype: Reference
        """

        return Reference(self.hybrid_shape_sweep_explicit.Spine)

    @spine.setter
    def spine(self, reference_spine: Reference):
        """
        :param Reference reference_spine:
        """

        self.hybrid_shape_sweep_explicit.Spine = reference_spine.com_object

    @property
    def sub_type(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property SubType() As long
                | 
                |     Returns or sets the explicit sweep subtype.
                |     Legal subtype values are:
                |     1 Explicit profile swept surface defined with reference
                |     surface
                |     2 Explicit profile swept surface defined with two guide
                |     curves
                |     3 Explicit profile swept surface defined with pulling
                |     direction

        :rtype: int
        """

        return self.hybrid_shape_sweep_explicit.SubType

    @sub_type.setter
    def sub_type(self, value: int):
        """
        :param int value:
        """

        self.hybrid_shape_sweep_explicit.SubType = value

    def get_angle_ref(self, ii: int) -> Angle:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Func GetAngleRef(long ii) As Angle
                | 
                |     Gets the angle value associated to the reference surface.
                | 
                |     Parameters:
                | 
                |         iI
                |             Angle value index (1: start value, 2: end value). 
                |         oElem
                |             Angle value. return value for CATScript applications, with
                |             (IDLRETVAL) function type 
                | 
                |     See also:
                |         Angle 
                |     See also:
                |         HybridShapeFactory

        :param int ii:
        :rtype: Angle
        """
        return Angle(self.hybrid_shape_sweep_explicit.GetAngleRef(ii))

    def get_fitting_points(self, op_ia_elem_a: Reference, op_ia_elem_b: Reference) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Sub GetFittingPoints(Reference opIAElemA,
                | Reference opIAElemB)
                | 
                |     Gets the fitting points : located in the profile plane, these points are used for two-guide
                |     swept surfaces to determine guide intersection locations.
                |     param opIAElem1 Fitting point associated to the first
                |     guide
                |     param opIAElem2 Fitting point associated to the second guide

        :param Reference op_ia_elem_a:
        :param Reference op_ia_elem_b:
        :rtype: None
        """
        return self.hybrid_shape_sweep_explicit.GetFittingPoints(op_ia_elem_a.com_object, op_ia_elem_b.com_object)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'get_fitting_points'
        # # vba_code = """
        # # Public Function get_fitting_points(hybrid_shape_sweep_explicit)
        # #     Dim opIAElemA (2)
        # #     hybrid_shape_sweep_explicit.GetFittingPoints opIAElemA
        # #     get_fitting_points = opIAElemA
        # # End Function
        # # """

        # # system_service = self.application.system_service
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def get_longitudinal_relimiters(self, op_ia_elem_a: Reference, op_ia_elem_b: Reference) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Sub GetLongitudinalRelimiters(Reference opIAElemA,
                | Reference opIAElemB)
                | 
                |     Deprecated:
                |         V5R16 CATHybridShapeSweepExplicit#GetRelimiters Returns the elements
                |         relimiting the spine (or the default spine).
                |         param : opIAElem1 First relimiting feature (plane or point)
                |         param : opIAElem2 Second relimiting feature (plane or point)

        :param Reference op_ia_elem_a:
        :param Reference op_ia_elem_b:
        :rtype: None
        """
        return self.hybrid_shape_sweep_explicit.GetLongitudinalRelimiters(op_ia_elem_a.com_object,
                                                                          op_ia_elem_b.com_object)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'get_longitudinal_relimiters'
        # # vba_code = """
        # # Public Function get_longitudinal_relimiters(hybrid_shape_sweep_explicit)
        # #     Dim opIAElemA (2)
        # #     hybrid_shape_sweep_explicit.GetLongitudinalRelimiters opIAElemA
        # #     get_longitudinal_relimiters = opIAElemA
        # # End Function
        # # """

        # # system_service = self.application.system_service
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def get_nb_angle(self, o_ang: int) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Sub GetNbAngle(long oAng)
                | 
                |     Returns the number of Angles.
                |     param : oAng Number of Angle.

        :param int o_ang:
        :rtype: None
        """
        return self.hybrid_shape_sweep_explicit.GetNbAngle(o_ang)

    def get_nb_guide(self, o_num: int) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Sub GetNbGuide(long oNum)
                | 
                |     Gets the number of guides curves.
                |     param : oNum Number of guide curves.

        :param int o_num:
        :rtype: None
        """
        return self.hybrid_shape_sweep_explicit.GetNbGuide(o_num)

    def get_nb_pos_angle(self, o_pos_ang: int) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Sub GetNbPosAngle(long oPosAng)
                | 
                |     Gets the number of numerical positioning parameters corresponding to angles
                |     from the default positions of the X axes.
                |     param : oPosAng Number of parameters

        :param int o_pos_ang:
        :rtype: None
        """
        return self.hybrid_shape_sweep_explicit.GetNbPosAngle(o_pos_ang)

    def get_nb_pos_coord(self, o_pos_coord: int) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Sub GetNbPosCoord(long oPosCoord)
                | 
                |     Gets the number of numerical positioning parameters corresponding to
                |     coordinates of the new axes systems origins.
                |     param oPosCoord Number of parameters

        :param int o_pos_coord:
        :rtype: None
        """
        return self.hybrid_shape_sweep_explicit.GetNbPosCoord(o_pos_coord)

    def get_pos_angle(self, ii: int) -> Angle:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Func GetPosAngle(long ii) As Angle
                | 
                |     Gets angles if both profile and first sweep plane axis systems from default
                |     positions.
                | 
                |     Parameters:
                | 
                |         iI
                |             Index of numerical positioning coordinates in profile (value 1) or
                |             first sweep plane (value 2) axis system. 
                |         oElem
                |             Angle value. return value for CATScript applications, with
                |             (IDLRETVAL) function type 
                | 
                |     See also:
                |         Angle 
                |     See also:
                |         HybridShapeFactory

        :param int ii:
        :rtype: Angle
        """
        return Angle(self.hybrid_shape_sweep_explicit.GetPosAngle(ii))

    def get_pos_coord(self, ii: int) -> Length:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Func GetPosCoord(long ii) As Length
                | 
                |     Gets translations coordinates if both profile axis system and first sweep
                |     plane axis system from default positions.
                | 
                |     Parameters:
                | 
                |         iI
                |             Index of numerical positioning coordinates in profile (value 1 or
                |             2) or first sweep plane (value 3 or 4) axis system.
                |             
                |         oElem
                |             Coordinate value. return value for CATScript applications, with
                |             (IDLRETVAL) function type 
                | 
                |     See also:
                |         Length 
                |     See also:
                |         HybridShapeFactory

        :param int ii:
        :rtype: Length
        """
        return Length(self.hybrid_shape_sweep_explicit.GetPosCoord(ii))

    def get_pos_direction(self, ii: int) -> Reference:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Func GetPosDirection(long ii) As Reference
                | 
                |     Gets the positioning directions : profile plane or first sweep plane X-axis direction.
                | 
                |     Parameters:
                | 
                |         iI
                |             Plane index : 1 for profile plane, 2 for first sweep plane. 
                |         oElem
                |             Direction element. return value for CATScript applications, with
                |             (IDLRETVAL) function type 
                | 
                |     See also:
                |         Reference 
                |     See also:
                |         HybridShapeFactory

        :param int ii:
        :rtype: Reference
        """
        return Reference(self.hybrid_shape_sweep_explicit.GetPosDirection(ii))

    def get_pos_point(self, ii: int) -> Reference:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Func GetPosPoint(long ii) As Reference
                | 
                |     Gets the points designated as the origins of the profile plane and first
                |     sweep plane.
                | 
                |     Parameters:
                | 
                |         iI
                |             Plane index : 1 for profile plane, 2 for first sweep plane. 
                |         oElem
                |             Origin point. return value for CATScript applications, with
                |             (IDLRETVAL) function type 
                | 
                |     See also:
                |         Reference 
                |     See also:
                |         HybridShapeFactory

        :param int ii:
        :rtype: Reference
        """
        return Reference(self.hybrid_shape_sweep_explicit.GetPosPoint(ii))

    def get_pos_swap_axes(self, ii: int) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Func GetPosSwapAxes(long ii) As long
                | 
                |     Gets axes inversion from previous definition for both profile plane and
                |     first sweep plane.
                | 
                |     Parameters:
                | 
                |         iI
                |             Axis system index (1 for profile plane, 2 for first sweep plane).
                |             
                |         oElem
                |             Inversion value:
                |             Inversion values :
                |             = 1 - CATGSMAxisInversionMode_None : no axis inverted.
                |             = 2 - CATGSMAxisInversionMode_X : only X axis inverted.
                |             = 3 - CATGSMAxisInversionMode_Y : only Y axis inverted.
                |             = 4 - CATGSMAxisInversionMode_Both : both axes inverted. 
                | 
                |     See also:
                |         HybridShapeFactory

        :param int ii:
        :rtype: int
        """
        return self.hybrid_shape_sweep_explicit.GetPosSwapAxes(ii)

    def get_relimiters(self, op_ia_elem1: Reference, op_orient1: int, op_ia_elem2: Reference, op_orient2: int) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Sub GetRelimiters(Reference opIAElem1,
                | long opOrient1,
                | Reference opIAElem2,
                | long opOrient2)
                | 
                |     Retrieves the elements relimiting the spine (or the default
                |     spine).
                | 
                |     Parameters:
                | 
                |         opIAElem1
                |             The first relimiting feature (plane or point) 
                |         opOrient1
                |             Split direction for the first relimitation
                |             0 means that the beginning of the spine (considering its
                |             orientation) is removed, 1 means that the end of the spine is removed
                |             
                |         opIAElem2
                |             The second relimiting feature (plane or point) 
                |         opOrient2
                |             Split direction for the second relimitation

        :param Reference op_ia_elem1:
        :param int op_orient1:
        :param Reference op_ia_elem2:
        :param int op_orient2:
        :rtype: None
        """
        return self.hybrid_shape_sweep_explicit.GetRelimiters(op_ia_elem1.com_object, op_orient1,
                                                              op_ia_elem2.com_object, op_orient2)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'get_relimiters'
        # # vba_code = """
        # # Public Function get_relimiters(hybrid_shape_sweep_explicit)
        # #     Dim opIAElem1 (2)
        # #     hybrid_shape_sweep_explicit.GetRelimiters opIAElem1
        # #     get_relimiters = opIAElem1
        # # End Function
        # # """

        # # system_service = self.application.system_service
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def is_sketch_axis_used_as_default(self, o_boolean: bool) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Sub IsSketchAxisUsedAsDefault(boolean oBoolean)
                | 
                |     Queries status wherere Sketch axis used as default or not.
                |     In case of a sketch profile, specify if the 2D sketch axis must be used as
                |     default planar profile axis (for positioning purpose) or
                |     not.
                |     param oBoolean TRUE if the 2D sketch axis must be used, FALSE if not.

        :param bool o_boolean:
        :rtype: None
        """
        return self.hybrid_shape_sweep_explicit.IsSketchAxisUsedAsDefault(o_boolean)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'is_sketch_axis_used_as_default'
        # # vba_code = """
        # # Public Function is_sketch_axis_used_as_default(hybrid_shape_sweep_explicit)
        # #     Dim oBoolean (2)
        # #     hybrid_shape_sweep_explicit.IsSketchAxisUsedAsDefault oBoolean
        # #     is_sketch_axis_used_as_default = oBoolean
        # # End Function
        # # """

        # # system_service = self.application.system_service
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def remove_angle(self) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Sub RemoveAngle()
                | 
                |     Removes an Angle.

        :rtype: None
        """
        return self.hybrid_shape_sweep_explicit.RemoveAngle()

    def remove_fitting_points(self) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Sub RemoveFittingPoints()
                | 
                |     Removes the fitting points.

        :rtype: None
        """
        return self.hybrid_shape_sweep_explicit.RemoveFittingPoints()

    def remove_guide(self) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Sub RemoveGuide()
                | 
                |     Removes a guide curve.

        :rtype: None
        """
        return self.hybrid_shape_sweep_explicit.RemoveGuide()

    def set_angle_ref(self, ii: int, elem: float) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Sub SetAngleRef(long ii,
                | double Elem)
                | 
                |     Sets the angle value associated to the reference surface.
                | 
                |     Parameters:
                | 
                |         iI
                |             Angle value index (1: start value, 2: end value). 
                |         iElem
                |             Angle value. 
                | 
                |     See also:
                |         HybridShapeFactory

        :param int ii:
        :param float elem:
        :rtype: None
        """
        return self.hybrid_shape_sweep_explicit.SetAngleRef(ii, elem)

    def set_fitting_points(self, ip_ia_elem_a: Reference, ip_ia_elem_b: Reference) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Sub SetFittingPoints(Reference ipIAElemA,
                | Reference ipIAElemB)
                | 
                |     Sets the fitting points.
                |     Does not work with NULL_var values, Use RemoveFittingPoints() method
                |     instead.
                |     param ipIAElem1 Fitting point associated to the first guide (must not be
                |     equal to NULL_var)
                |     param ipIAElem2 Fitting point associated to the second guide (can be equal
                |     to NULL_var)

        :param Reference ip_ia_elem_a:
        :param Reference ip_ia_elem_b:
        :rtype: None
        """
        return self.hybrid_shape_sweep_explicit.SetFittingPoints(ip_ia_elem_a.com_object, ip_ia_elem_b.com_object)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'set_fitting_points'
        # # vba_code = """
        # # Public Function set_fitting_points(hybrid_shape_sweep_explicit)
        # #     Dim ipIAElemA (2)
        # #     hybrid_shape_sweep_explicit.SetFittingPoints ipIAElemA
        # #     set_fitting_points = ipIAElemA
        # # End Function
        # # """

        # # system_service = self.application.system_service
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def set_guide_deviation(self, i_length: float) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Sub SetGuideDeviation(double iLength)
                | 
                |     Sets deviation value (length) from guide curves allowed during sweeping.
                |     operation in order to smooth it.
                |     param : iLength Numerical value.

        :param float i_length:
        :rtype: None
        """
        return self.hybrid_shape_sweep_explicit.SetGuideDeviation(i_length)

    def set_longitudinal_relimiters(self, ip_ia_elem_a: Reference, ip_ia_elem_b: Reference) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Sub SetLongitudinalRelimiters(Reference ipIAElemA,
                | Reference ipIAElemB)
                | 
                |     Deprecated:
                |         V5R16 CATHybridShapeSweepExplicit#SetRelimiters Sets the elements
                |         relimiting the spine (or the default spine).
                |         param : ipIAElem1 First relimiting feature (plane or point)
                |         param : ipIAElem2 Second relimiting feature (plane or point)

        :param Reference ip_ia_elem_a:
        :param Reference ip_ia_elem_b:
        :rtype: None
        """
        return self.hybrid_shape_sweep_explicit.SetLongitudinalRelimiters(ip_ia_elem_a.com_object,
                                                                          ip_ia_elem_b.com_object)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'set_longitudinal_relimiters'
        # # vba_code = """
        # # Public Function set_longitudinal_relimiters(hybrid_shape_sweep_explicit)
        # #     Dim ipIAElemA (2)
        # #     hybrid_shape_sweep_explicit.SetLongitudinalRelimiters ipIAElemA
        # #     set_longitudinal_relimiters = ipIAElemA
        # # End Function
        # # """

        # # system_service = self.application.system_service
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def set_pos_angle(self, ii: int, elem: float) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Sub SetPosAngle(long ii,
                | double Elem)
                | 
                |     Sets angles if both profile and first sweep plane axis systems from default
                |     positions.
                | 
                |     Parameters:
                | 
                |         iI
                |             Index of numerical positioning coordinates in profile (value 1) or
                |             first sweep plane (value 2) axis system. 
                |         iElem
                |             Angle value. 
                | 
                |     See also:
                |         HybridShapeFactory

        :param int ii:
        :param float elem:
        :rtype: None
        """
        return self.hybrid_shape_sweep_explicit.SetPosAngle(ii, elem)

    def set_pos_coord(self, ii: int, elem: float) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Sub SetPosCoord(long ii,
                | double Elem)
                | 
                |     Sets translations coordinates if both profile axis system and first sweep
                |     plane axis system from default positions.
                | 
                |     Parameters:
                | 
                |         iI
                |             Index of numerical positioning coordinates in profile (value 1 or
                |             2) or first sweep plane (value 3 or 4) axis system.
                |             
                |         iElem
                |             Coordinate value. 
                | 
                |     See also:
                |         HybridShapeFactory

        :param int ii:
        :param float elem:
        :rtype: None
        """
        return self.hybrid_shape_sweep_explicit.SetPosCoord(ii, elem)

    def set_pos_direction(self, ii: int, elem: Reference) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Sub SetPosDirection(long ii,
                | Reference Elem)
                | 
                |     Sets the positioning directions : profile plane or first sweep plane X-axis direction.
                | 
                |     Parameters:
                | 
                |         iI
                |             Plane index : 1 for profile plane, 2 for first sweep plane. 
                |         iElem
                |             Direction element. 
                | 
                |     See also:
                |         Reference 
                |     See also:
                |         HybridShapeFactory

        :param int ii:
        :param Reference elem:
        :rtype: None
        """
        return self.hybrid_shape_sweep_explicit.SetPosDirection(ii, elem.com_object)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'set_pos_direction'
        # # vba_code = """
        # # Public Function set_pos_direction(hybrid_shape_sweep_explicit)
        # #     Dim ii (2)
        # #     hybrid_shape_sweep_explicit.SetPosDirection ii
        # #     set_pos_direction = ii
        # # End Function
        # # """

        # # system_service = self.application.system_service
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def set_pos_point(self, ii: int, elem: Reference) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Sub SetPosPoint(long ii,
                | Reference Elem)
                | 
                |     Sets the points designated as the origins of the profile plane and first
                |     sweep plane.
                | 
                |     Parameters:
                | 
                |         iI
                |             Plane index : 1 for profile plane, 2 for first sweep plane. 
                |         iElem
                |             Origin point. 
                | 
                |     See also:
                |         Reference 
                |     See also:
                |         HybridShapeFactory

        :param int ii:
        :param Reference elem:
        :rtype: None
        """
        return self.hybrid_shape_sweep_explicit.SetPosPoint(ii, elem.com_object)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'set_pos_point'
        # # vba_code = """
        # # Public Function set_pos_point(hybrid_shape_sweep_explicit)
        # #     Dim ii (2)
        # #     hybrid_shape_sweep_explicit.SetPosPoint ii
        # #     set_pos_point = ii
        # # End Function
        # # """

        # # system_service = self.application.system_service
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def set_pos_swap_axes(self, ii: int, elem: int) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Sub SetPosSwapAxes(long ii,
                | long Elem)
                | 
                |     Sets axes inversion from previous definition for both profile plane and
                |     first sweep plane.
                | 
                |     Parameters:
                | 
                |         iI
                |             Axis system index (1 for profile plane, 2 for first sweep plane).
                |             
                |         iElem
                |             Inversion value:
                | 
                |             Inversion values :
                |             = 1 - CATGSMAxisInversionMode_None : no axis inverted.
                |             = 2 - CATGSMAxisInversionMode_X : only X axis inverted.
                |             = 3 - CATGSMAxisInversionMode_Y : only Y axis inverted.
                |             = 4 - CATGSMAxisInversionMode_Both : both axes inverted. 
                | 
                |     See also:
                |         HybridShapeFactory

        :param int ii:
        :param int elem:
        :rtype: None
        """
        return self.hybrid_shape_sweep_explicit.SetPosSwapAxes(ii, elem)

    def set_relimiters(self, ip_ia_elem1: Reference, ip_orient1: int, ip_ia_elem2: Reference, ip_orient2: int) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Sub SetRelimiters(Reference ipIAElem1,
                | long ipOrient1,
                | Reference ipIAElem2,
                | long ipOrient2)
                | 
                |     Sets the elements relimiting the spine (or the default
                |     spine).
                | 
                |     Parameters:
                | 
                |         ipIAElem1
                |             The first relimiting feature (plane or point) 
                |         ipOrient1
                |             Split direction for the first relimitation
                |             0 means that the beginning of the spine (considering its
                |             orientation) is removed, 1 means that the end of the spine is removed
                |             
                |         ipIAElem2
                |             The second relimiting feature (plane or point) 
                |         ipOrient2
                |             Split direction for the second relimitation

        :param Reference ip_ia_elem1:
        :param int ip_orient1:
        :param Reference ip_ia_elem2:
        :param int ip_orient2:
        :rtype: None
        """
        return self.hybrid_shape_sweep_explicit.SetRelimiters(ip_ia_elem1.com_object, ip_orient1,
                                                              ip_ia_elem2.com_object, ip_orient2)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'set_relimiters'
        # # vba_code = """
        # # Public Function set_relimiters(hybrid_shape_sweep_explicit)
        # #     Dim ipIAElem1 (2)
        # #     hybrid_shape_sweep_explicit.SetRelimiters ipIAElem1
        # #     set_relimiters = ipIAElem1
        # # End Function
        # # """

        # # system_service = self.application.system_service
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def set_smooth_angle_threshold(self, i_angle: float) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Sub SetSmoothAngleThreshold(double iAngle)
                | 
                |     Sets angular threshold.
                |     param : iAngle Numerical value.

        :param float i_angle:
        :rtype: None
        """
        return self.hybrid_shape_sweep_explicit.SetSmoothAngleThreshold(i_angle)

    def use_sketch_axis_as_default(self, i_boolean: bool) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Sub UseSketchAxisAsDefault(boolean iBoolean)
                | 
                |     Uses Sketch Axis As Default.
                |     In case of a sketch profile, specify if the 2D sketch axis must be used as
                |     default planar profile axis (for positioning purpose) or
                |     not.
                |     param iBoolean TRUE if the 2D sketch axis must be used, FALSE if not.

        :param bool i_boolean:
        :rtype: None
        """
        return self.hybrid_shape_sweep_explicit.UseSketchAxisAsDefault(i_boolean)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'use_sketch_axis_as_default'
        # # vba_code = """
        # # Public Function use_sketch_axis_as_default(hybrid_shape_sweep_explicit)
        # #     Dim iBoolean (2)
        # #     hybrid_shape_sweep_explicit.UseSketchAxisAsDefault iBoolean
        # #     use_sketch_axis_as_default = iBoolean
        # # End Function
        # # """

        # # system_service = self.application.system_service
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def __repr__(self):
        return f'HybridShapeSweepExplicit(name="{self.name}")'



#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-09-25 14:34:21.593357

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""
from pycatia.abq_automation_interfaces.abq_analysis_cases import ABQAnalysisCases
from pycatia.abq_automation_interfaces.abq_properties import ABQProperties
from pycatia.system_interfaces.any_object import AnyObject


class ABQAnalysisModel(AnyObject):
    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.AnyObject
                |                     ABQAnalysisModel
                | 
                | Represents the Abaqus analysis model object.
                | Role: The Abaqus analysis model object contains the ABQAnalysisCases
                | collection. The Abaqus analysis model object can also be used as an Refer:
                | CATIAAnalysisModel.
    
    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.abq_analysis_model = com_object

    @property
    def cases(self) -> ABQAnalysisCases:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property Cases() As ABQAnalysisCases (Read Only)
                | 
                |     Returns the list of Abaqus analysis cases associated with the analysis
                |     model.
                | 
                |     Returns:
                |         The collection of Abaqus analysis cases. 
                |     Example:
                |         The following example retrieves the Abaqus analysis cases collection
                |         analysisCases:
                | 
                |          Dim analysisCases As ABQAnalysisCases
                |          Dim abqModel As ABQAnalysisModel
                |          Set analysisCases = abqModel.Cases

        :rtype: ABQAnalysisCases
        """

        return ABQAnalysisCases(self.abq_analysis_model.Cases)

    @property
    def properties(self) -> ABQProperties:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property Properties() As ABQProperties (Read Only)
                | 
                |     Returns the list of Abaqus properties associated with the analysis
                |     model.
                | 
                |     Returns:
                |         The collection of Abaqus properties. 
                |     Example:
                |         The following example retrieves the Abaqus properties collection
                |         properties:
                | 
                |          Dim properties As ABQProperties
                |          Dim abqModel As ABQAnalysisModel
                |          Set properties = abqModel.Properties

        :rtype: ABQProperties
        """

        return ABQProperties(self.abq_analysis_model.Properties)

    def __repr__(self):
        return f'ABQAnalysisModel(name="{self.name}")'



#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-09-25 14:34:21.593357

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""
from pycatia.cat_plant_ship_interfaces.psp_connector import PSPConnector
from pycatia.cat_plant_ship_interfaces.psp_list_of_bstrs import PSPListOfBSTRs
from pycatia.cat_plant_ship_interfaces.psp_list_of_objects import PSPListOfObjects
from pycatia.system_interfaces.any_object import AnyObject


class PSPConnectable(AnyObject):
    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.AnyObject
                |                     PspConnectable
                | 
                | Represents an Interface to manage object behaviors in making
                | connections.
                | Role: To specify object behaviors such as adding a connector and removing a
                | connector.
    
    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.psp_connectable = com_object

    @property
    def connectors(self) -> PSPListOfObjects:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property Connectors() As PspListOfObjects (Read Only)
                | 
                |     Returns a list of connectors of the object.
                | 
                |     Example:
                |
                |          Dim objThisIntf As PspConnectable
                |          Dim objArg1 As CatPspIDLDomainID
                |          Dim objArg2 As PspListOfBSTRs
                |           ...
                |          Set objArg2 = objThisIntf.Connectors

        :rtype: PSPListOfObjects
        """

        return PSPListOfObjects(self.psp_connectable.Connectors)

    @property
    def valid_connector_types(self) -> PSPListOfBSTRs:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property ValidConnectorTypes() As PspListOfBSTRs (Read
                | Only)
                | 
                |     Returns a list of Valid connector types on this object.
                | 
                |     Example:
                |
                |          Dim objThisIntf As PspConnectable
                |          Dim objArg1 As PspListOfBSTRs  
                |           ...
                |          Set objArg1 = objThisIntf.ValidConnectorTypes

        :rtype: PSPListOfBSTRs
        """

        return PSPListOfBSTRs(self.psp_connectable.ValidConnectorTypes)

    def get_connector_by_name(self, iu_connector_name: str) -> PSPConnector:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func GetConnectorByName(CATBSTR iuConnectorName) As
                | PspConnector
                | 
                |     Retrieves a connector with the given name.
                | 
                |     Parameters:
                | 
                |         iConnectorName
                |             Connector name to look for. 
                | 
                |     Returns:
                |         Connector with given name.
                |
                |     Example:
                |
                |          Dim objThisIntf As PspConnectable
                |          Dim strVar1 As PspListOfBSTRs
                |          Dim objArg2 As PspConnector
                |           ...
                |          Set objArg2 = objThisIntf.GetConnectorByName (strVar1)

        :param str iu_connector_name:
        :rtype: PSPConnector
        """
        return PSPConnector(self.psp_connectable.GetConnectorByName(iu_connector_name))

    def list_connectables(
            self,
            iu_class_filter: PSPListOfBSTRs,
            o_l_cntbles: PSPListOfObjects,
            o_l_cntrs_on_this_obj: PSPListOfObjects,
            o_l_cntrs_on_connected: PSPListOfObjects
    ) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub ListConnectables(PspListOfBSTRs iuClassFilter,
                | PspListOfObjects oLCntbles,
                | PspListOfObjects oLCntrsOnThisObj,
                | PspListOfObjects oLCntrsOnConnected)
                | 
                |     Retrieve a list of connectors of the object.
                | 
                |     Parameters:
                | 
                |         iuClassFilter
                |             Class filter list. If iuClassFilter is an empty list then it will
                |             get connectors for all the application connector types.
                |             
                |         oLCntbles
                |             a list of CATIAPspConnectable objects that connect this object
                |             
                |         oLCntrsOnThisObj
                |             a list of connectors on "this" object in the connections ( A list
                |             of CATIAPspConnector) 
                |         oLCntrsOnConnected
                |             a list of connectors on the other objects that the member of the
                |             former list is connected to (positions in oLCntrsOnThisObj and
                |             oLCntrsOnConnected corresponds to each other) ( A list of CATIAPspConnector)
                |
                |     Example:
                |
                |          Dim objThisIntf As PspConnectable
                |          Dim objArg1 As PspListOfBSTRs
                |          Dim objArg2 As PspListofObjects
                |          Dim objArg3 As PspListofObjects
                |          Dim objArg4 As PspListofObjects
                |           ...
                |          objThisIntf.ListConnectables
                |          objArg1,objArg2,objArg3,objArg4

        :param PSPListOfBSTRs iu_class_filter:
        :param PSPListOfObjects o_l_cntbles:
        :param PSPListOfObjects o_l_cntrs_on_this_obj:
        :param PSPListOfObjects o_l_cntrs_on_connected:
        :rtype: None
        """
        return self.psp_connectable.ListConnectables(
            iu_class_filter.com_object,
            o_l_cntbles.com_object,
            o_l_cntrs_on_this_obj.com_object,
            o_l_cntrs_on_connected.com_object
        )
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'list_connectables'
        # # vba_code = """
        # # Public Function list_connectables(psp_connectable)
        # #     Dim iuClassFilter (2)
        # #     psp_connectable.ListConnectables iuClassFilter
        # #     list_connectables = iuClassFilter
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def __repr__(self):
        return f'PSPConnectable(name="{self.name}")'



#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-09-25 14:34:21.593357

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""
from pycatia.abq_automation_interfaces.abq_data_output_request import ABQDataOutputRequest
from pycatia.system_interfaces.collection import Collection
from pycatia.types.general import cat_variant


class ABQDataOutputRequests(Collection):
    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.Collection
                |                     ABQDataOutputRequests
                | 
                | The collection of Abaqus data output request (ABQDataOutputRequest) objects
                | attached to an
                | ABQGeneralStaticStep, an ABQFrequencyStep, or an ABQHeatTransferStep
                | object.
    
    """

    def __init__(self, com_object):
        super().__init__(com_object, child_object=ABQDataOutputRequest)
        self.abq_data_output_requests = com_object

    def add(self) -> ABQDataOutputRequest:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func Add() As ABQDataOutputRequest
                | 
                |     Creates a new Abaqus data output request and adds it to the collection of
                |     Abaqus data output requests.
                | 
                |     Returns:
                |         oDataOutputRequest The Abaqus data output request object that was
                |         created. 
                |     Example:
                |         The following example creates a data output request in the
                |         ABQDataOutputRequests collection:
                | 
                |          Dim abqDataOutputRequests As ABQDataOutputRequests
                |          Set abqDataOutputRequests = generalstaticstep.DataOutputRequests
                |          Dim abqDataOutputRequest As ABQDataOutputRequest
                |          Set abqDataOutputRequest =  abqDataOutputRequests.Add()

        :rtype: ABQDataOutputRequest
        """
        return ABQDataOutputRequest(self.abq_data_output_requests.Add())

    def item(self, i_index: cat_variant) -> ABQDataOutputRequest:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func Item(CATVariant iIndex) As ABQDataOutputRequest
                | 
                |     Returns an Abaqus data output request using its index or its name from the
                |     ABQDataOutputRequests collection.
                | 
                |     Parameters:
                | 
                |         iIndex
                |             The index or the name of the Abaqus data output request to retrieve
                |             from the collection of Abaqus data output requests. If the index is a number,
                |             it specifies the rank of the Abaqus data output request in the collection. The
                |             index of the first Abaqus data output request in the collection is 1, and the
                |             index of the last data output request is Count. If the index is a string, it
                |             specifies the name you assigned to the data output request using the
                |             CATIACollection::Name property. 
                | 
                |     Returns:
                |         The specified ABQDataOutputRequest.

        :param cat_variant i_index:
        :rtype: ABQDataOutputRequest
        """
        return ABQDataOutputRequest(self.abq_data_output_requests.Item(i_index))

    def remove(self, i_index: cat_variant) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub Remove(CATVariant iIndex)
                | 
                |     Removes an Abaqus data output request using its index or its name from the
                |     data output requests collection.
                | 
                |     Parameters:
                | 
                |         iIndex
                |             The index or the name of the data output request to retrieve from
                |             the collection of data output requests. As a numeric, this index is the rank of
                |             the data output request in the collection. The index of the first data output
                |             request in the collection is 1, and the index of the last data output request
                |             is Count. As a string, it is the name you assigned to the data output request
                |             using the CATIABase::Name property.

        :param cat_variant i_index:
        :rtype: None
        """
        return self.abq_data_output_requests.Remove(i_index)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'remove'
        # # vba_code = """
        # # Public Function remove(abq_data_output_requests)
        # #     Dim iIndex (2)
        # #     abq_data_output_requests.Remove iIndex
        # #     remove = iIndex
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def __repr__(self):
        return f'ABQDataOutputRequests(name="{self.name}")'



#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-09-25 14:34:21.593357

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""

from pycatia.system_interfaces.collection import Collection
from pycatia.cat_mat_interfaces.material import Material
from pycatia.types.general import cat_variant


class Materials(Collection):
    """
    .. note::
        :class: toggle

        CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)

            | System.IUnknown
            |     System.IDispatch
            |         System.CATBaseUnknown
            |             System.CATBaseDispatch
            |                 System.Collection
            |                     Materials
            |
            | A collection of all the Material objects.
            | This collection is currently managed by a MaterialFamily
            | object.

    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.materials = com_object

    def add(self) -> Material:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func Add() As Material
                |
                |     Adds a new material to the material collection.

        :rtype: Material
        """
        return Material(self.materials.Add())

    def item(self, i_index: cat_variant) -> Material:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func Item(CATVariant iIndex) As Material
                |
                |     Returns a material from its index in the Material
                |     collection.
                |
                |     Parameters:
                |
                |         iIndex
                |             The index of the material to retrieve in the
                |             collection of materials. Compared with other
                |             collections, you cannot use the name of the
                |             material as argument.
                |
                |     Returns:
                |         The retrieved material
                |
                | Example:
                |     The following example returns in MyMaterial the sixth
                |     material in a material collection.
                |
                |      Dim MyMaterial As Material
                |      Set MyMaterial = Materials.Item(6)

        :param cat_variant i_index:
        :rtype: Material
        """
        return Material(self.materials.Item(i_index))

    def remove(self, i_index: cat_variant) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub Remove(CATVariant iIndex)
                |
                |     Removes a material from the materials collection.

        :param cat_variant i_index:
        :rtype: None
        """
        self.materials.Remove(i_index)

    def sorted_item(self, i_index: cat_variant, i_mode: int) -> Material:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func SortedItem(CATVariant iIndex,
                | short iMode) As Material
                |
                |     Returns a material from its index in the sorted Material
                |     collection.
                |
                |     Parameters:
                |
                |         iIndex
                |             The index of the material to retrieve in the
                |             sorted collection of materials. Compared with
                |             other collections, you cannot use the name of the
                |             material as argument.
                |         iMode
                |             The sorted mode of material collection
                |
                |                 Possible mode values are:
                |                 0: Alphabetical order
                |                 1: Inverse alphabetical order
                |
                |     Returns:
                |         The retrieved material

        :param cat_variant i_index:
        :param int i_mode:
        :rtype: Material
        """
        return Material(self.materials.SortedItem(i_index, i_mode))

    def __repr__(self):
        return f'Materials(name="{self.name}")'



#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-09-25 14:34:21.593357

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""
from pycatia.cat_sch_platform_interfaces.sch_list_of_objects import SchListOfObjects
from pycatia.system_interfaces.any_object import AnyObject


class SchInternalFlow(AnyObject):
    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.AnyObject
                |                     SchInternalFlow
                | 
                | Represents the internal flow object in a schematic component.
    
    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.sch_internal_flow = com_object

    def get_insertion_type(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub GetInsertionType(CatSchIDLInternalFlowType
                | oEInternalFlowType)
                | 
                |     Get insertion flow type.
                | 
                |     Parameters:
                | 
                |         oEInternalFlowType
                |             Internal flow type. 
                | 
                |     Example:
                |
                |          Dim objThisIntf As SchInternalFlow
                | 
                |           ...
                |          objThisIntf.GetInsertionTypeCatSchIDLInternalFlowType_Enum

        :return: enum cat_sch_idl_internal_flow_type
        :rtype: None
        """
        return self.sch_internal_flow.GetInsertionType()

    def get_status(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub GetStatus(CatSchIDLInternalFlowStatus
                | oEInternalFlowStatus)
                | 
                |     Get insertion flow status.
                | 
                |     Parameters:
                | 
                |         oEInternalFlowStatus
                |             Internal flow status. 
                | 
                |     Example:
                |
                |          Dim objThisIntf As SchInternalFlow
                | 
                |           ...
                |          objThisIntf.GetStatusCatSchIDLInternalFlowStatus_Enum

        :return: enum cat_sch_idl_internal_flow_status
        :rtype: int
        """
        return self.sch_internal_flow.GetStatus()

    def list_sch_connectors(self) -> SchListOfObjects:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func ListSchConnectors() As SchListOfObjects
                | 
                |     List all schematic connectors associated with an internal
                |     flow.
                | 
                |     Parameters:
                | 
                |         oLSchCntrs
                |             A list of schematic connector objects (members are
                |             CATISchCntrLocation interface pointers). 
                | 
                |     Example:
                |
                |          Dim objThisIntf As SchInternalFlow
                |          Dim objArg1 As SchListOfObjects
                |           ...
                |          Set objArg1 = objThisIntf.ListSchConnectors

        :rtype: SchListOfObjects
        """
        return SchListOfObjects(self.sch_internal_flow.ListSchConnectors())

    def set_status(self, i_e_internal_flow_status: int) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub SetStatus(CatSchIDLInternalFlowStatus
                | iEInternalFlowStatus)
                | 
                |     Set insertion flow status.
                | 
                |     Parameters:
                | 
                |         iEInternalFlowStatus
                |             Internal flow status. 
                | 
                |     Example:
                |
                |          Dim objThisIntf As SchInternalFlow
                | 
                |           ...
                |          objThisIntf.SetStatusCatSchIDLInternalFlowStatus_Enum

        :param int i_e_internal_flow_status: enum cat_sch_idl_internal_flow_status
        :rtype: None
        """
        return self.sch_internal_flow.SetStatus(i_e_internal_flow_status)

    def __repr__(self):
        return f'SchInternalFlow(name="{self.name}")'



#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-06-11 12:40:47.360445

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""

from pycatia.knowledge_interfaces.enum_param import EnumParam


class BoolParam(EnumParam):
    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.AnyObject
                |                     KnowledgeInterfaces.Parameter
                |                         KnowledgeInterfaces.EnumParam
                |                             BoolParam
                | 
                | Represents the boolean parameter.
                | The following example shows how to create it:
                | 
                |   Dim CATDocs As Documents
                |   Set CATDocs      = CATIA.Documents
                |   Dim part1 As Document
                |   Set part1        = CATDocs.Add("CATPart")
                |   Dim availability As BooleanParam
                |   Set availability = part1.Parameters.CreateBoolean("availability", True)
    
    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.bool_param = com_object

    @property
    def value(self) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445)
                | o Property Value() As boolean
                | 
                |     Returns or sets the value of the boolean parameter.
                | 
                |     Example:
                |         This example sets the availability boolean parameter value to True if
                |         its value is False:
                | 
                |          If (availability.Value = False)  Then
                |              availability.Value = True
                |          End If

        :rtype: bool
        """

        return self.bool_param.Value

    @value.setter
    def value(self, value: bool):
        """
        :param bool value:
        """

        self.bool_param.Value = value

    def __repr__(self):
        return f'BoolParam(name="{self.name}")'



#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-09-25 14:34:21.593357

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""
from pycatia.kinematics_interfaces.mechanism_command import MechanismCommand
from pycatia.system_interfaces.collection import Collection
from pycatia.types.general import cat_variant


class MechanismCommands(Collection):
    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.Collection
                |                     MechanismCommands
                | 
                | A collection of all MechanismCommand entities currently managed by the
                | application.
    
    """

    def __init__(self, com_object):
        super().__init__(com_object, child_object=MechanismCommand)
        self.mechanism_commands = com_object

    def add(self) -> MechanismCommand:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func Add() As MechanismCommand
                | 
                |     Creates a new MechanismCommand and adds it to the MechanismCommands
                |     collection.
                | 
                |     Returns:
                |         The created MechanismCommand 
                |     Example:
                |         This example creates a new MechanismCommand in the TheCommands
                |         collection.
                | 
                |             Dim NewCommand As MechanismCommand
                |             Set NewCommand = TheCommands.Add()

        :rtype: MechanismCommand
        """
        return MechanismCommand(self.mechanism_commands.Add())

    def item(self, i_index: cat_variant) -> MechanismCommand:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func Item(CATVariant iIndex) As MechanismCommand
                | 
                |     Returns a MechanismCommand using its index or its name from the Commands
                |     collection.
                | 
                |     Parameters:
                | 
                |         iIndex
                |             The index or the name of the MechanismCommand to retrieve from the
                |             collection of Commands. As a numerics, this index is the rank of the
                |             MechanismCommand in the collection. The index of the first MechanismCommand in
                |             the collection is 1, and the index of the last MechanismCommand is Count. As a
                |             string, it is the name you assigned to the MechanismCommand using the
                |             
                | 
                |         AnyObject.Name property. 
                |     Returns:
                |         The retrieved MechanismCommand 
                |     Example:
                |         This example returns in ThisCommand the third MechanismCommand in the
                |         collection, and in ThatCommand the MechanismCommand named
                |         MyCommand.
                | 
                |          Dim ThisCommand As MechanismCommand
                |          Set ThisCommand = TheCommands.Item(3)
                |          Dim ThatCommand As MechanismCommand
                |          Set ThatCommand = CATIA.MechanismCommands.Item("MyCommand")

        :param cat_variant i_index:
        :rtype: MechanismCommand
        """
        return MechanismCommand(self.mechanism_commands.Item(i_index))

    def remove(self, i_index: cat_variant) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub Remove(CATVariant iIndex)
                | 
                |     Remove a MechanismCommand from the MechanismCommands
                |     collection.
                | 
                |     Parameters:
                | 
                |         iIndex
                |             The index or the name of the MechanismCommand to retrieve from the
                |             collection of MechanismCommands. As a numerics, this index is the rank of the
                |             MechanismCommand in the collection. The index of the first MechanismCommand in
                |             the collection is 1, and the index of the last MechanismCommand is Count. As a
                |             string, it is the name you assigned to the MechanismCommand.
                |             
                | 
                |     Returns:
                |         Nothing 
                |     Example:
                |         The following example removes the tenth MechanismCommand and the
                |         MechanismCommand named CommandTwo from the TheCommands
                |         collection.
                | 
                |             TheCommands.Remove(10)
                |             TheCommands.Remove("CommandTwo")

        :param cat_variant i_index:
        :rtype: None
        """
        return self.mechanism_commands.Remove(i_index)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'remove'
        # # vba_code = """
        # # Public Function remove(mechanism_commands)
        # #     Dim iIndex (2)
        # #     mechanism_commands.Remove iIndex
        # #     remove = iIndex
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def __repr__(self):
        return f'MechanismCommands(name="{self.name}")'



#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-09-25 14:34:21.593357

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""
from pycatia.manufacturing_interfaces.manufacturing_machinable_feature import ManufacturingMachinableFeature
from pycatia.types.general import cat_variant


class ManufacturingMachinableArea(ManufacturingMachinableFeature):
    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.AnyObject
                |                    ManufacturingInterfaces.ManufacturingFeature
                |                        ManufacturingInterfaces.ManufacturingMachinableFeature
                |                             ManufacturingMachinableArea
                | 
                | Machinable Area in Manufacturing.
                | It is a manufacturing feature pointing design features through one or several
                | machinable geometry. This manufacturing feature could be a target for a
                | manufacturing activity.
                | 
                | See also:
                |     ManufacturingMachinableGeometry, ManufacturingActivity
    
    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.manufacturing_machinable_area = com_object

    @property
    def frozen(self) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property Freezed() As boolean
                | 
                |     Returns the manufacturing machinable area freezed state.
                | 
                |     Returns:
                |         oFreezed The manufacturing machinable area freezed state
                |         
                |     Example:
                |         The following example returns in bFreezed the freezed state of
                |         manufacturing machinable area firstMachArea:
                | 
                |          Dim firstMachArea As ManufacturingMachinableArea
                |          Set firstMachArea = ...
                |          Dim bFreezed As boolean
                |          Set bFreezed = firstMachArea.Freezed

        :rtype: bool
        """

        return self.manufacturing_machinable_area.Freezed

    @frozen.setter
    def frozen(self, value: bool):
        """
        :param bool value:
        """

        self.manufacturing_machinable_area.Freezed = value

    @property
    def visible_in_mfg_view(self) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property VisibleInMfgView() As boolean
                | 
                |     Returns the manufacturing machinable area visibility
                |     state.
                | 
                |     Returns:
                |         oVisibleInMfgView The manufacturing machinable area visibility state
                |         
                |     Example:
                |         The following example returns in bVisibleInMfgView the visible state in
                |         the Manufacturing View of manufacturing machinable area
                |         firstMachArea:
                | 
                |          Dim firstMachArea As ManufacturingMachinableArea
                |          Set firstMachArea = ...
                |          Dim bVisibleInMfgView As boolean
                |          Set bVisibleInMfgView = firstMachArea.VisibleInMfgView

        :rtype: bool
        """

        return self.manufacturing_machinable_area.VisibleInMfgView

    @visible_in_mfg_view.setter
    def visible_in_mfg_view(self, value: bool):
        """
        :param bool value:
        """

        self.manufacturing_machinable_area.VisibleInMfgView = value

    def add_machinable_geometry(self, i_machinable_geometry: ManufacturingMachinableFeature) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub AddMachinableGeometry(ManufacturingMachinableFeature
                | iMachinableGeometry)
                | 
                |     Adds a machinable geometry to the list.
                | 
                |     Parameters:
                | 
                |         iMachinableGeometry
                |             The machinable geometry to affect 
                | 
                |     Example:
                |         The following example adds the machinable geometry MachGeomToAdd to the
                |         manufacturing machinable area firstMachArea.
                | 
                |          Dim firstMachArea As ManufacturingMachinableArea
                |          Set firstMachArea = ...
                |          Dim MachGeomToAdd As ManufacturingMachinableGeometry
                |          Set MachGeomToAdd = ...
                |          Call firstMachArea.AddMachinableGeometry( MachGeomToAdd
                |          )

        :param ManufacturingMachinableFeature i_machinable_geometry:
        :rtype: None
        """
        return self.manufacturing_machinable_area.AddMachinableGeometry(i_machinable_geometry.com_object)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'add_machinable_geometry'
        # # vba_code = """
        # # Public Function add_machinable_geometry(manufacturing_machinable_area)
        # #     Dim iMachinableGeometry (2)
        # #     manufacturing_machinable_area.AddMachinableGeometry iMachinableGeometry
        # #     add_machinable_geometry = iMachinableGeometry
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def list_machinable_geometry(self, o_list_of_machinable_geometry: tuple) -> cat_variant:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub ListMachinableGeometry(CATSafeArrayVariant
                | oListOfMachinableGeometry)
                | 
                |     Retrieves the machinable geometry list.
                | 
                |     Parameters:
                | 
                |         oListOfMachinableGeometry
                |             The retrieved list.
                |             The array must be previously initialized using the
                |             
                | 
                |         MachinableGeometryCount method. 
                | 
                | Example:
                |     The following example retrieves the machinable geometry list of the
                |     manufacturing machinable area firstMachArea in
                |     MachinableGeometryList.
                | 
                |      Dim firstMachArea As ManufacturingMachinableArea
                |      Set firstMachArea = ...
                |      Dim MachinableGeometryListSize As Long
                |      Set MachinableGeometryListSize = firstMachArea.MachinableGeometryCount
                |      If MachinableGeometryListSize > 0 Then
                |        Dim MachinableGeometryList() As Variant
                |        Redim
                |        MachinableGeometryList(MachinableGeometryListSize-1)
                |        Call firstMachArea.ListMachinableGeometry(MachinableGeometryList)
                |      End If

        :param tuple o_list_of_machinable_geometry:
        :rtype: cat_variant
        """
        return self.manufacturing_machinable_area.ListMachinableGeometry(o_list_of_machinable_geometry)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'list_machinable_geometry'
        # # vba_code = """
        # # Public Function list_machinable_geometry(manufacturing_machinable_area)
        # #     Dim oListOfMachinableGeometry (2)
        # #     manufacturing_machinable_area.ListMachinableGeometry oListOfMachinableGeometry
        # #     list_machinable_geometry = oListOfMachinableGeometry
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def list_manufacturing_activity_connected(self, o_list_of_manufacturing_activity_connected: tuple) -> cat_variant:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub ListManufacturingActivityConnected(CATSafeArrayVariant
                | oListOfManufacturingActivityConnected)
                | 
                |     Retrieves the manufacturing activity connected list.
                | 
                |     Parameters:
                | 
                |         oListOfManufacturingActivityConnected
                |             The retrieved list.
                |             The array must be previously initialized using the
                |             
                | 
                |         ManufacturingActivityConnectedCount method. 
                | 
                | Example:
                |     The following example retrieves the manufacturing activity connected list
                |     of the manufacturing machinable area firstMachArea in
                |     ManufacturingActivityConnectedList.
                | 
                |      Dim firstMachArea As ManufacturingMachinableArea
                |      Set firstMachArea = ...
                |      Dim ManufacturingActivityConnectedListSize As Long
                |      Set ManufacturingActivityConnectedListSize = firstMachArea.ManufacturingActivityConnectedCount
                |      If ManufacturingActivityConnectedListSize > 0 Then
                |        Dim ManufacturingActivityConnectedList() As Variant
                |        Redim ManufacturingActivityConnectedList(ManufacturingActivityConnectedListSize-1)
                |        Call firstMachArea.ListManufacturingActivityConnected(ManufacturingActivityConnectedList)
                |      End If

        :param tuple o_list_of_manufacturing_activity_connected:
        :rtype: cat_variant
        """
        return self.manufacturing_machinable_area.ListManufacturingActivityConnected(
            o_list_of_manufacturing_activity_connected)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'list_manufacturing_activity_connected'
        # # vba_code = """
        # # Public Function list_manufacturing_activity_connected(manufacturing_machinable_area)
        # #     Dim oListOfManufacturingActivityConnected (2)
        # #     manufacturing_machinable_area.ListManufacturingActivityConnected oListOfManufacturingActivityConnected
        # #     list_manufacturing_activity_connected = oListOfManufacturingActivityConnected
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def machinable_geometry_count(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func MachinableGeometryCount() As long
                | 
                |     Returns the machinable geometry list count.
                | 
                |     Parameters:
                | 
                |         oMachinableGeometryCount
                |             The number of machinable geometry connected to this feature
                |
                |     Example:
                |         The following example retrieves the machinable geometry list count of
                |         the manufacturing machinable area firstMachArea in
                |         MachinableGeometryListSize.
                | 
                |          Dim firstMachArea As ManufacturingMachinableArea
                |          Set firstMachArea = ...
                |          Dim MachinableGeometryListSize As Long
                |          Set MachinableGeometryListSize = firstMachArea.MachinableGeometryCount

        :rtype: int
        """
        return self.manufacturing_machinable_area.MachinableGeometryCount()

    def manufacturing_activity_connected_count(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func ManufacturingActivityConnectedCount() As long
                | 
                |     Returns the manufacturing activity connected list count.
                | 
                |     Parameters:
                | 
                |         oManufacturingActivityConnectedCount
                |             The number of manufacturing activity pointing this feature
                |
                |     Example:
                |         The following example retrieves the manufacturing activity connected
                |         list count of the manufacturing machinable area firstMachArea in
                |         ManufacturingActivityConnectedListSize.
                | 
                |          Dim firstMachArea As ManufacturingMachinableArea
                |          Set firstMachArea = ...
                |          Dim ManufacturingActivityConnectedListSize As Long
                |          Set ManufacturingActivityConnectedListSize = firstMachArea.ManufacturingActivityConnectedCount

        :rtype: int
        """
        return self.manufacturing_machinable_area.ManufacturingActivityConnectedCount()

    def remove_machinable_geometry(self, i_machinable_geometry: ManufacturingMachinableFeature) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub RemoveMachinableGeometry(ManufacturingMachinableFeature
                | iMachinableGeometry)
                | 
                |     Removes a machinable geometry from the list.
                | 
                |     Parameters:
                | 
                |         iMachinableGeometry
                |             The machinable geometry to remove 
                | 
                |     Example:
                |         The following example removes the machinable geometry MachGeomToRemove
                |         to the manufacturing machinable area firstMachArea.
                | 
                |          Dim firstMachArea As ManufacturingMachinableArea
                |          Set firstMachArea = ...
                |          Dim MachGeomToRemove As
                |          ManufacturingMachinableGeometry
                |          Set MachGeomToRemove = ...
                |          Call firstMachArea.RemoveMachinableGeometry( MachGeomToRemove
                |          )

        :param ManufacturingMachinableFeature i_machinable_geometry:
        :rtype: None
        """
        return self.manufacturing_machinable_area.RemoveMachinableGeometry(i_machinable_geometry.com_object)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'remove_machinable_geometry'
        # # vba_code = """
        # # Public Function remove_machinable_geometry(manufacturing_machinable_area)
        # #     Dim iMachinableGeometry (2)
        # #     manufacturing_machinable_area.RemoveMachinableGeometry iMachinableGeometry
        # #     remove_machinable_geometry = iMachinableGeometry
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def __repr__(self):
        return f'ManufacturingMachinableArea(name="{self.name}")'



#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-09-25 14:34:21.593357

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""

from pycatia.in_interfaces.document import Document
from pycatia.navigator_interfaces.group import Group
from pycatia.product_structure_interfaces.product import Product
from pycatia.system_interfaces.collection import Collection


class ThreeDCuts(Collection):
    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.Collection
                |                     ThreeDCuts
                | 
                | Interface to compute 3D cuts
    
    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.three_d_cuts = com_object

    def compute_3d_cut(self, group_of_selected_products: Group, three_d_cut_document: Document) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub Compute3DCut(Group GroupOfSelectedProducts,
                | Document ThreeDCutDocument)
                | 
                |     Computes the 3DCut on the selected products.
                | 
                |     Parameters:
                | 
                |         GroupOfSelectedProducts
                |             The selected products on which you want to perform the 3D cut.
                |             
                | 
                |     Returns:
                |         ThreeDCutDocument: Document containing the result.

        :param Group group_of_selected_products:
        :param Document three_d_cut_document:
        :rtype: None
        """
        return self.three_d_cuts.Compute3DCut(group_of_selected_products.com_object, three_d_cut_document.com_object)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'compute3_d_cut'
        # # vba_code = """
        # # Public Function compute3_d_cut(three_d_cuts)
        # #     Dim GroupOfSelectedProducts (2)
        # #     three_d_cuts.Compute3DCut GroupOfSelectedProducts
        # #     compute3_d_cut = GroupOfSelectedProducts
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def compute3_d_cut_with_a_reference(
            self,
            group_of_selected_products: Group,
            i_reference_product: Product,
            three_d_cut_document: Document
    ) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub Compute3DCutWithAReference(Group
                | GroupOfSelectedProducts,
                | Product iReferenceProduct,
                | Document ThreeDCutDocument)
                | 
                |     Computes the 3DCut on the selected products, according to a reference
                |     product.
                | 
                |     Parameters:
                | 
                |         GroupOfSelectedProducts
                |             The selected products on which you want to perform the 3D cut.
                |             
                |         iReferenceProduct
                |             Product taken as a reference. 
                | 
                |     Returns:
                |         ThreeDCutDocument: Document containing the result.

        :param Group group_of_selected_products:
        :param Product i_reference_product:
        :param Document three_d_cut_document:
        :rtype: None
        """
        return self.three_d_cuts.Compute3DCutWithAReference(
            group_of_selected_products.com_object,
            i_reference_product.com_object,
            three_d_cut_document.com_object
        )
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'compute3_d_cut_with_a_reference'
        # # vba_code = """
        # # Public Function compute3_d_cut_with_a_reference(three_d_cuts)
        # #     Dim GroupOfSelectedProducts (2)
        # #     three_d_cuts.Compute3DCutWithAReference GroupOfSelectedProducts
        # #     compute3_d_cut_with_a_reference = GroupOfSelectedProducts
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def get_compute_3d_cut(self, group_of_selected_products: Group) -> Document:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func GetCompute3DCut(Group GroupOfSelectedProducts) As
                | Document
                | 
                |     Computes the 3DCut on the selected products (better
                |     signature).
                | 
                |     Parameters:
                | 
                |         GroupOfSelectedProducts
                |             The selected products on which you want to perform the 3D cut.
                |             
                | 
                |     Returns:
                |         ThreeDCutDocument: Document containing the result.

        :param Group group_of_selected_products:
        :rtype: Document
        """
        return Document(self.three_d_cuts.GetCompute3DCut(group_of_selected_products.com_object))

    def get_compute_3d_cut_with_a_reference(
            self,
            group_of_selected_products: Group,
            i_reference_product: Product
    ) -> Document:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func GetCompute3DCutWithAReference(Group
                | GroupOfSelectedProducts,
                | Product iReferenceProduct) As Document
                | 
                |     Computes the 3DCut on the selected products, according to a reference
                |     product (better signature).
                | 
                |     Parameters:
                | 
                |         GroupOfSelectedProducts
                |             The selected products on which you want to perform the 3D cut.
                |             
                |         iReferenceProduct
                |             Product taken as a reference. 
                | 
                |     Returns:
                |         ThreeDCutDocument: Document containing the result.

        :param Group group_of_selected_products:
        :param Product i_reference_product:
        :rtype: Document
        """
        return Document(
            self.three_d_cuts.GetCompute3DCutWithAReference(
                group_of_selected_products.com_object,
                i_reference_product.com_object
            )
        )

    def set_box(self, origin_x: float, origin_y: float, origin_z: float, vx: float, vy: float, vz: float) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub SetBox(double OriginX,
                | double OriginY,
                | double OriginZ,
                | double VX,
                | double VY,
                | double VZ)
                | 
                |     Sets the RELATIVE box used for the 3D cut computation.
                |     Be aware of the behavior:
                | 
                |             Vz
                |            ^_________________
                |           /|               /|
                |          /                / |
                |         /  |             /  |
                |        /                /   |
                |       /----+-----------/    |
                |       |                |    |
                |       |    |       *   |    |
                |       |            O   |    |
                |       |    |           |    |
                |       |                |    |
                |       |    |           |    |
                |       |    * - - - - - + - -|> Vy
                |       |    Origin      |   / 
                |       |  /             |  /
                |       |                | /
                |       |/               |/
                |       /----------------/
                |      <
                |       Vx
                | 
                |     In the relative referential, O is (0,0,0)
                | 
                |     This method sets the RELATIVE box : the rotation and translation matrix will then set the absolute position of O.
                |     Remember where the center of the relative referential lies!
                |     Can have unexpected results if you don't use it properly.
                | 
                |     Parameters:
                | 
                |         OriginX
                |             Origin coordinate (X) 
                |         OriginY
                |             Origin coordinate (Y) 
                |         OriginZ
                |             Origin coordinate (Z) 
                |         VX
                |             Length of the box (along X) 
                |         VY
                |             Length of the box (along Y) 
                |         VZ
                |             Length of the box (along Z)

        :param float origin_x:
        :param float origin_y:
        :param float origin_z:
        :param float vx:
        :param float vy:
        :param float vz:
        :rtype: None
        """
        return self.three_d_cuts.SetBox(origin_x, origin_y, origin_z, vx, vy, vz)

    def set_matrix(self, i_components: tuple) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub SetMatrix(CATSafeArrayVariant iComponents)
                | 
                |     Sets the rotation AND translation matrix.
                |     Beware : After a SetBox, the matrix is not changed.
                | 
                |     Parameters:
                | 
                |         iComponents
                |             Components of the 4x4 matrix, placed in rows.

        :param tuple i_components:
        :rtype: None
        """
        return self.three_d_cuts.SetMatrix(i_components)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'set_matrix'
        # # vba_code = """
        # # Public Function set_matrix(three_d_cuts)
        # #     Dim iComponents (2)
        # #     three_d_cuts.SetMatrix iComponents
        # #     set_matrix = iComponents
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def set_on_borders(self, on_borders: int) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub SetOnBorders(long OnBorders)
                | 
                |     Sets the behavior on borders.
                | 
                |     Parameters:
                | 
                |         Type
                |             0 : We keep partially included triangles
                |             1 : We keep entirely included triangles

        :param int on_borders:
        :rtype: None
        """
        return self.three_d_cuts.SetOnBorders(on_borders)

    def set_type(self, type: int) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub SetType(long Type)
                | 
                |     Sets the type of cut we're doing.
                | 
                |     Parameters:
                | 
                |         Type
                |             0 : We keep the inner triangles
                |             1 : We keep the outer triangles

        :param int type:
        :rtype: None
        """
        return self.three_d_cuts.SetType(type)

    def three_d_cut_shape_name(self, name: str) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub ThreeDCutShapeName(CATBSTR Name)
                | 
                |     Returns the name of the associated shape.

        :param str name:
        :rtype: None
        """
        return self.three_d_cuts.ThreeDCutShapeName(name)

    def __repr__(self):
        return f'ThreeDCuts(name="{self.name}")'



#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-09-25 14:34:21.593357

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""
from pycatia.arrangement_interfaces.arrangement_areas import ArrangementAreas
from pycatia.arrangement_interfaces.arrangement_boundaries import ArrangementBoundaries
from pycatia.arrangement_interfaces.arrangement_item_reservations import ArrangementItemReservations
from pycatia.arrangement_interfaces.arrangement_pathways import ArrangementPathways
from pycatia.arrangement_interfaces.arrangement_rectangles import ArrangementRectangles
from pycatia.arrangement_interfaces.arrangement_runs import ArrangementRuns
from pycatia.system_interfaces.any_object import AnyObject


class ArrangementProduct(AnyObject):
    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.AnyObject
                |                     ArrangementProduct
                | 
                | Use this object as a factory for Arrangement collection
                | objects.
                | Role: Use this interface to get access to the Arrangement collections (Areas,
                | Rectangles, ItemReservations, Runs, Pathways, Boundaries) aggregated a given
                | Product.
    
    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.arrangement_product = com_object

    @property
    def arrangement_areas(self) -> ArrangementAreas:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property ArrangementAreas() As ArrangementAreas (Read Only)
                | 
                |     Returns the collection of ArrangementAreas under the current
                |     ArrangementProduct.
                | 
                |     Example:
                |         This example retrieves the ArrangementAreas collection, oArrAreas , for
                |         the objArrProd1 ArrangementProduct object.
                | 
                |          Dim oArrAreas As ArrangementAreas
                |          Set oArrAreas = objArrProd1.Areas

        :rtype: ArrangementAreas
        """

        return ArrangementAreas(self.arrangement_product.ArrangementAreas)

    @property
    def arrangement_boundaries(self) -> ArrangementBoundaries:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property ArrangementBoundaries() As ArrangementBoundaries (Read
                | Only)
                | 
                |     Returns the collection of ArrangementBoundaries under the current
                |     ArrangementProduct.
                | 
                |     Example:
                |         This example retrieves the ArrangementBoundaries collection,
                |         oArrBoundaries , for the objArrProd1 ArrangementProduct
                |         object.
                | 
                |          Dim oArrBoundaries As ArrangementBoundaries
                |          Set oArrBoundaries = objArrProd1.oArrObjType

        :rtype: ArrangementBoundaries
        """

        return ArrangementBoundaries(self.arrangement_product.ArrangementBoundaries)

    @property
    def arrangement_item_reservations(self) -> ArrangementItemReservations:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property ArrangementItemReservations() As ArrangementItemReservations (Read
                | Only)
                | 
                |     Returns the collection of ArrangementItemReservations under the current
                |     ArrangementProduct.
                | 
                |     Example:
                |         This example retrieves the ArrangementItemReservations collection,
                |         oArrItemReservations , for the objArrProd1 ArrangementProduct
                |         object.
                | 
                |          Dim oArrItemReservations As
                |          ArrangementItemReservations
                |          Set oArrItemReservations = objArrProd1.ItemReservations

        :rtype: ArrangementItemReservations
        """

        return ArrangementItemReservations(self.arrangement_product.ArrangementItemReservations)

    @property
    def arrangement_pathways(self) -> ArrangementPathways:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property ArrangementPathways() As ArrangementPathways (Read
                | Only)
                | 
                |     Returns the collection of ArrangementPathways under the current
                |     ArrangementProduct.
                | 
                |     Example:
                |         This example retrieves the ArrangementPathways collection, oArrPathways
                |         , for the objArrProd1 ArrangementProduct object.
                | 
                |          Dim oArrPathways As ArrangementPathways
                |          Set oArrPathways = objArrProd1.Pathways

        :rtype: ArrangementPathways
        """

        return ArrangementPathways(self.arrangement_product.ArrangementPathways)

    @property
    def arrangement_rectangles(self) -> ArrangementRectangles:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property ArrangementRectangles() As ArrangementRectangles (Read
                | Only)
                | 
                |     Returns the collection of ArrangementRectangles under the current
                |     ArrangementProduct.
                | 
                |     Example:
                |         This example retrieves the ArrangementRectangles collection,
                |         oArrRectangles , for the objArrProd1 ArrangementProduct
                |         object.
                | 
                |          Dim oArrRectangles As ArrangementRectangles
                |          Set oArrRectangles = objArrProd1.Rectangles

        :rtype: ArrangementRectangles
        """

        return ArrangementRectangles(self.arrangement_product.ArrangementRectangles)

    @property
    def arrangement_runs(self) -> ArrangementRuns:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property ArrangementRuns() As ArrangementRuns (Read Only)
                | 
                |     Returns the collection of ArrangementRuns under the current
                |     ArrangementProduct.
                | 
                |     Example:
                |         This example retrieves the ArrangementRuns collection, oArrRuns , for
                |         the objArrProd1 ArrangementProduct object.
                | 
                |          Dim oArrRuns As ArrangementRuns
                |          Set oArrRuns = objArrProd1.Runs

        :rtype: ArrangementRuns
        """

        return ArrangementRuns(self.arrangement_product.ArrangementRuns)

    @property
    def type(self) -> str:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property Type() As CATBSTR (Read Only)
                | 
                |     Returns the Type of the ArrangementProduct in the form of a
                |     String.
                | 
                |     Example:
                |         This example retrieves the type information as a string for the
                |         objArrProd1 ArrangementProduct object.
                | 
                |          Dim oArrObjType  As String
                |          oArrObjType  = objArrProd1.Type

        :rtype: str
        """

        return self.arrangement_product.Type

    def get_technological_object(self, i_application_type: str) -> AnyObject:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func GetTechnologicalObject(CATBSTR iApplicationType) As
                | CATBaseDispatch
                | 
                |     Returns the product's applicative data which type is the given
                |     parameter.
                | 
                |     Parameters:
                | 
                |         iApplicationType
                |             The type of applicative data searched. 
                |         oApplicativeObj
                |             The matched applicative object.
                | 
                |             Example:
                |                 This example retrieves the desired applicative object from the
                |                 objArrProd1 object.
                | 
                |                  Dim objProd   As Product
                |                  objProd  = objArrProd1.GetTechnologicalObject("Product")

        :param str i_application_type:
        :rtype: AnyObject
        """
        return self.arrangement_product.GetTechnologicalObject(i_application_type)

    def set_arrangement_nomenclature(self, i_nomenclature: str) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub SetArrangementNomenclature(CATBSTR iNomenclature)
                | 
                |     Sets the nomenclature of the ArrangementProduct.
                | 
                |     Returns:
                |         An HRESULT value.
                |         Legal values:
                | 
                |         S_OK
                |             operation is successful
                |         E_FAIL
                |             operation failed
                | 
                |         Example:
                |             This example sets the ArrangementNomenclature for objArrProd1
                |             ArrangementProduct object.
                | 
                |              objArrProd1.SetArrangementNomenclature = "Building"

        :param str i_nomenclature:
        :rtype: None
        """
        return self.arrangement_product.SetArrangementNomenclature(i_nomenclature)

    def set_auto_name(self) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub SetAutoName()
                | 
                |     Causes the name of the ArrangementProduct automatically.
                | 
                |     Returns:
                |         An HRESULT value.
                |         Legal values:
                | 
                |         S_OK
                |             operation is successful
                |         E_FAIL
                |             operation failed
                | 
                |         Example:
                |             This example shows how the automatic naming of the objArrProd1
                |             ArrangementProduct object can be done.
                | 
                |              objArrProd1.SetAutoName

        :rtype: None
        """
        return self.arrangement_product.SetAutoName()

    def __repr__(self):
        return f'ArrangementProduct(name="{self.name}")'



#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-09-25 14:34:21.593357

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""
from pycatia.manufacturing_interfaces.manufacturing_feature import ManufacturingFeature


class ManufacturingMachinableFeature(ManufacturingFeature):
    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.AnyObject
                |                    ManufacturingInterfaces.ManufacturingFeature
                |                         ManufacturingMachinableFeature
                | 
                | Machinable Feature in Manufacturing.
                | It is the base object for machinable geometry and machinable
                | area
                | 
                | See also:
                |     ManufacturingMachinableArea, ManufacturingMachinableGeometry
    
    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.manufacturing_machinable_feature = com_object

    @property
    def feat_remark(self) -> str:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property FeatRemark() As CATBSTR
                | 
                |     Returns the manufacturing machinable feature remark.
                | 
                |     Returns:
                |         oFeatRemark The manufacturing machinable feature remark
                |         
                |     Example:
                |         The following example returns in tFeatRemark the remark of
                |         manufacturing machinable feature firstMachFeat:
                | 
                |          Dim firstMachFeat As ManufacturingMachinableFeature
                |          Set firstMachFeat = ...
                |          Dim tFeatRemark As CATBSTR
                |          Set tFeatRemark = firstMachFeat.FeatRemark

        :rtype: str
        """

        return self.manufacturing_machinable_feature.FeatRemark

    @feat_remark.setter
    def feat_remark(self, value: str):
        """
        :param str value:
        """

        self.manufacturing_machinable_feature.FeatRemark = value

    @property
    def feat_type(self) -> str:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property FeatType() As CATBSTR
                | 
                |     Returns the manufacturing machinable feature type.
                | 
                |     Returns:
                |         oFeatType The manufacturing machinable feature type 
                |     Example:
                |         The following example returns in tFeatType the type of manufacturing
                |         machinable feature firstMachFeat:
                | 
                |          Dim firstMachFeat As ManufacturingMachinableFeature
                |          Set firstMachFeat = ...
                |          Dim tFeatType As CATBSTR
                |          Set tFeatType = firstMachFeat.FeatType

        :rtype: str
        """

        return self.manufacturing_machinable_feature.FeatType

    @feat_type.setter
    def feat_type(self, value: str):
        """
        :param str value:
        """

        self.manufacturing_machinable_feature.FeatType = value

    def __repr__(self):
        return f'ManufacturingMachinableFeature(name="{self.name}")'



#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-07-06 14:02:20.222384

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""

from pycatia.hybrid_shape_interfaces.hybrid_shape_direction import HybridShapeDirection
from pycatia.in_interfaces.reference import Reference
from pycatia.knowledge_interfaces.length import Length
from pycatia.mec_mod_interfaces.hybrid_shape import HybridShape


class HybridShapeCorner(HybridShape):

    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.AnyObject
                |                     MecModInterfaces.HybridShape
                |                         HybridShapeCorner
                | 
                | Represents the hybrid shape corner feature.
                | Role: To access the data of the hybrid shape corner object. This data
                | includes:
                | 
                |     Two elements
                |     Their orientations (same or inverse than the underlying
                |     curve)
                |     A support for the hybrid shape corner on support feature
                |     A direction for the hybrid shape 3D corner feature
                |     A radius.
                | 
                | Use the HybridShapeFactory to create a HybridShapeCorner
                | object.
    
    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.hybrid_shape_corner = com_object

    @property
    def begin_of_corner(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property BeginOfCorner() As long
                | 
                |     Return or Set the number of the beginning curve of the corner. This
                |     parameter is used to stabilize the resulting corner
                | 
                |     Example:
                | 
                |           This example set the beginning wire index of
                |          the hybShpCorner hybrid shape corner 
                |          
                | 
                |          hybShpCorner.BeginOfCorner = 1

        :rtype: int
        """

        return self.hybrid_shape_corner.BeginOfCorner

    @begin_of_corner.setter
    def begin_of_corner(self, value: int):
        """
        :param int value:
        """

        self.hybrid_shape_corner.BeginOfCorner = value

    @property
    def corner_type(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property CornerType() As long
                | 
                |     Returns or sets the Corner Type.
                | 
                |     Example:
                | 
                |           This example retrieves the Corner Type 
                |          the hybShpCorner hybrid shape corner in CornerType.
                |          
                | 
                |          Dim lCornerType As long
                |          lCornerType = hybShpCorner.CornerType

        :rtype: int
        """

        return self.hybrid_shape_corner.CornerType

    @corner_type.setter
    def corner_type(self, value: int):
        """
        :param int value:
        """

        self.hybrid_shape_corner.CornerType = value

    @property
    def direction(self) -> HybridShapeDirection:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property Direction() As HybridShapeDirection
                | 
                |     Returns or sets the 3D corner direction.
                |     Legal values: This can be a CATIAHybridShapeDirection.
                | 
                |     See also:
                |         HybridShapeDirection 
                |     Example:
                | 
                |           This example sets the direction of
                |          the hybShpCorner hybrid shape 3D corner as
                |          the existing direction hybShpDirection.
                |          
                | 
                |          hybShpCorner.Direction = hybShpDirection

        :rtype: HybridShapeDirection
        """

        return HybridShapeDirection(self.hybrid_shape_corner.Direction)

    @direction.setter
    def direction(self, direction: HybridShapeDirection):
        """
        :param HybridShapeDirection direction:
        """

        self.hybrid_shape_corner.Direction = direction.com_object

    @property
    def discrimination_index(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property DiscriminationIndex() As long
                | 
                |     Returns or set the discrimination index of the current corner. Several
                |     resulting solutions produced by the operator can be same oriented regarding to
                |     the input wire bodies. In such a case, they are sorted in order to distinguish
                |     them. The Sequence FirstOrientation - SecondOrientation - DiscriminationIndex
                |     allows you to identify a unique one-domain solution.
                | 
                |     Example:
                | 
                |           This example set the discrimination index of
                |          the hybShpCorner hybrid shape corner 
                |          
                | 
                |          hybShpCorner.DiscriminationIndex = 2

        :rtype: int
        """

        return self.hybrid_shape_corner.DiscriminationIndex

    @discrimination_index.setter
    def discrimination_index(self, value: int):
        """
        :param int value:
        """

        self.hybrid_shape_corner.DiscriminationIndex = value

    @property
    def first_elem(self) -> Reference:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property FirstElem() As Reference
                | 
                |     Returns or sets the corner first reference element.
                |     Legal values: This can be a curve or a point.
                |     Sub-element(s) supported (see Boundary object): TriDimFeatEdge,
                |     BiDimFeatEdge or Vertex.
                | 
                |     Example:
                | 
                |           This example retrieves the first reference element
                |           of
                |          the hybShpCorner hybrid shape corner in firstElt.
                |          
                | 
                |          Dim fisrtElt As CATIAReference
                |          fisrtElt = hybShpCorner.FirstElem

        :rtype: Reference
        """

        return Reference(self.hybrid_shape_corner.FirstElem)

    @first_elem.setter
    def first_elem(self, reference_element: Reference):
        """
        :param Reference reference_element:
        """

        self.hybrid_shape_corner.FirstElem = reference_element.com_object

    @property
    def first_orientation(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property FirstOrientation() As long
                | 
                |     Returns or sets the orientation of the corner first reference element. The
                |     orientation specifies the corner center position. It is either the same of the
                |     inverse orientation than those of the cross product: Normal(Support) ^
                |     Tangent(FirstElem)
                |     Legal values: 1 if the orientation of the corner first reference element is
                |     the same than the cross product: Normal(Support) ^ Tangent(FirstElem), and -1
                |     if it is the inverse.
                | 
                |     Example:
                | 
                |           This example retrieves the orientation of first reference element
                |           of
                |          the hybShpCorner hybrid shape corner in firstOrient.
                |          
                | 
                |          Dim firstOrient As long
                |          firstOrient = hybShpCorner.FirstOrientation

        :rtype: int
        """

        return self.hybrid_shape_corner.FirstOrientation

    @first_orientation.setter
    def first_orientation(self, value: int):
        """
        :param int value:
        """

        self.hybrid_shape_corner.FirstOrientation = value

    @property
    def first_tangent_orientation(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property FirstTangentOrientation() As long
                | 
                |     Returns or sets the tangent orientation of the corner first reference
                |     element. compared to the corner itself
                | 
                |     Example:
                | 
                |           This example retrieves the tangent orientation of first reference
                |           element of
                |          the hybShpCorner hybrid shape corner in firstOrient.
                |          
                | 
                |          Dim firstOrient As long
                |          firstOrient = hybShpCorner.FirstTangentOrientation

        :rtype: int
        """

        return self.hybrid_shape_corner.FirstTangentOrientation

    @first_tangent_orientation.setter
    def first_tangent_orientation(self, value: int):
        """
        :param int value:
        """

        self.hybrid_shape_corner.FirstTangentOrientation = value

    @property
    def on_vertex(self) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property OnVertex() As boolean
                | 
                |     Returns or sets the On Vertex mode off/on.
                | 
                |     Example:
                | 
                |           This example retrieves the OnVertex
                |          the hybShpCorner hybrid shape corner in OnVertex.
                |          
                | 
                |          Dim bOnVertex As boolean
                |          bOnVertex = hybShpCorner.OnVertex

        :rtype: bool
        """

        return self.hybrid_shape_corner.OnVertex

    @on_vertex.setter
    def on_vertex(self, value: bool):
        """
        :param bool value:
        """

        self.hybrid_shape_corner.OnVertex = value

    @property
    def radius(self) -> Length:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property Radius() As Length (Read Only)
                | 
                |     Returns the corner radius.
                | 
                |     Example:
                | 
                |           This example retrieves the radius of
                |          the hybShpCorner hybrid shape corner in radius.
                |          
                | 
                |          Dim radius As CATIALength
                |          radius = hybShpCorner.Radius

        :rtype: Length
        """

        return Length(self.hybrid_shape_corner.Radius)

    @property
    def second_elem(self) -> Reference:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property SecondElem() As Reference
                | 
                |     Returns or sets the corner second reference element.
                |     Legal values: This is always a curve.
                |     Sub-element(s) supported (see Boundary object): TriDimFeatEdge,
                |     BiDimFeatEdge or Vertex.
                | 
                |     Example:
                | 
                |           This example retrieves the second reference element
                |           of
                |          the hybShpCorner hybrid shape corner in secondElt.
                |          
                | 
                |          Dim secondElt As CATIAReference
                |          secondElt = hybShpCorner.SecondElem

        :rtype: Reference
        """

        return Reference(self.hybrid_shape_corner.SecondElem)

    @second_elem.setter
    def second_elem(self, reference_element: Reference):
        """
        :param Reference reference_element:
        """

        self.hybrid_shape_corner.SecondElem = reference_element.com_object

    @property
    def second_orientation(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property SecondOrientation() As long
                | 
                |     Returns or sets the orientation of the corner second reference element. The
                |     orientation specifies the corner center position. It is either the same of the
                |     inverse orientation than those of the cross product: Normal(Support) ^
                |     Tangent(SecondElem)
                |     Legal values: 1 if the orientation of the corner second reference element
                |     is the same than the cross product: Normal(Support) ^ Tangent(SecondElem), and
                |     -1 if it is the inverse.
                | 
                |     Example:
                | 
                |           This example sets the orientation of second reference element
                |           of
                |          the hybShpCorner hybrid shape corner to the inverse of the cross
                |          porduct
                |          Normal(Support) ^ Tangent(SecondElem).
                |          
                | 
                |          hybShpCorner.SecondOrientation = -1

        :rtype: int
        """

        return self.hybrid_shape_corner.SecondOrientation

    @second_orientation.setter
    def second_orientation(self, value: int):
        """
        :param int value:
        """

        self.hybrid_shape_corner.SecondOrientation = value

    @property
    def second_tangent_orientation(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property SecondTangentOrientation() As long
                | 
                |     Returns or sets the tangent orientation of the corner second reference
                |     element. compared to the corner itself
                | 
                |     Example:
                | 
                |           This example retrieves the tangent orientation of second reference
                |           element of
                |          the hybShpCorner hybrid shape corner in secondOrient.
                |          
                | 
                |          Dim secondOrient As long
                |          firstOrient = hybShpCorner.SecondTangentOrientation

        :rtype: int
        """

        return self.hybrid_shape_corner.SecondTangentOrientation

    @second_tangent_orientation.setter
    def second_tangent_orientation(self, value: int):
        """
        :param int value:
        """

        self.hybrid_shape_corner.SecondTangentOrientation = value

    @property
    def support(self) -> Reference:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property Support() As Reference
                | 
                |     Returns or sets the corner support.
                |     Legal values: This can be a plane or a surface.
                |     Sub-element(s) supported (see Boundary object): Face.
                | 
                |     Example:
                | 
                |           This example sets the support of
                |          the hybShpCorner hybrid shape corner as
                |          the existing surface supportSurf.
                |          
                | 
                |          hybShpCorner.Support = supportSurf

        :rtype: Reference
        """

        return Reference(self.hybrid_shape_corner.Support)

    @support.setter
    def support(self, reference_support: Reference):
        """
        :param Reference reference_support:
        """

        self.hybrid_shape_corner.Support = reference_support.com_object

    @property
    def trim(self) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property Trim() As boolean
                | 
                |     Returns or sets whether the corner reference curves are or should be
                |     trimmed.
                |     Legal values: True if the corner reference curves are or should be trimmed,
                |     and False otherwise.
                | 
                |     Example:
                | 
                |           This example sets that the corner reference curves
                |           of
                |          the hybShpCorner hybrid shape corner should be
                |          trimmed.
                |          
                | 
                |          hybShpCorner.Trim = True

        :rtype: bool
        """

        return self.hybrid_shape_corner.Trim

    @trim.setter
    def trim(self, value: bool):
        """
        :param bool value:
        """

        self.hybrid_shape_corner.Trim = value

    @property
    def trim_mode(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property TrimMode() As long
                | 
                |     Returns or sets whether the corner reference curves are or should be
                |     trimmed.
                |     Legal values: 1 if the corner reference curves are or should be trimmed, 0
                |     if the corner reference curves are not or should not be trimmed, 2 if only the
                |     first corner reference curve is or should be trimmed, 3 if only the second
                |     corner reference curve is or should be trimmed,
                | 
                |     Example:
                | 
                |           This example sets that the corner reference curves
                |           of
                |          the hybShpCorner hybrid shape corner should be
                |          trimmed.
                |          
                | 
                |          hybShpCorner.TrimMode = 1

        :rtype: int
        """

        return self.hybrid_shape_corner.TrimMode

    @trim_mode.setter
    def trim_mode(self, value: int):
        """
        :param int value:
        """

        self.hybrid_shape_corner.TrimMode = value

    def invert_first_orientation(self) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Sub InvertFirstOrientation()
                | 
                |     Inverts the first reference element orientation used to compute the
                |     corner.
                | 
                |     Example:
                | 
                |           This example inverts the first corner reference element orientation
                |           of
                |          the hybShpCorner.
                |          
                | 
                |          hybShpCorner.InvertFirstOrientation

        :rtype: None
        """
        return self.hybrid_shape_corner.InvertFirstOrientation()

    def invert_second_orientation(self) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Sub InvertSecondOrientation()
                | 
                |     Inverts the second reference element orientation used to compute the
                |     corner.
                | 
                |     Example:
                | 
                |           This example inverts the second corner reference element orientation
                |           of
                |          the hybShpCorner.
                |          
                | 
                |          hybShpCorner.InvertSecondOrientation

        :rtype: None
        """
        return self.hybrid_shape_corner.InvertSecondOrientation()

    def __repr__(self):
        return f'HybridShapeCorner(name="{ self.name }")'



#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-09-25 14:34:21.593357

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""

from pycatia.system_interfaces.any_object import AnyObject


class SampledsNode(AnyObject):

    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.AnyObject
                |                     SampledsNode
                | 
                | The interface to access a CATIASampledsNode.
                | Role: The SampledsNode interface can be used to obtain different types of
                | Sampled based collections from within the current action
                | document.
    
    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.sampleds_node = com_object

    def get_sampleds(self, i_collection_name: str) -> AnyObject:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func GetSampleds(CATBSTR iCollectionName) As
                | CATBaseDispatch
                | 
                |     Retrieves a sampleds based collection of objects
                | 
                |     Parameters:
                | 
                |         iCollectionName
                |             The name of the collection to retrieve. 
                | 
                |     Returns:
                |         The requested collection 
                |     Example:
                |         The following example retrieves the collection of Track objects (called
                |         CATIATracks) from within the current document.
                | 
                |          Dim myTracks as Tracks
                |          Set myTracks = SampledsNode.GetSampleds ("Tracks")

        :param str i_collection_name:
        :rtype: AnyObject
        """
        return self.sampleds_node.GetSampleds(i_collection_name)

    def __repr__(self):
        return f'SampledsNode(name="{ self.name }")'
